# 52 "src/reason_lexer.mll"
 
open Lexing
open Misc
open Reason_parser

type error =
  | Illegal_character of char
  | Illegal_escape of string
  | Unterminated_comment of Location.t
  | Unterminated_string
  | Unterminated_string_in_comment of Location.t * Location.t
  | Keyword_as_label of string
  | Literal_overflow of string
;;

exception Error of error * Location.t;;


(* [splitToken s] looks at the token split table, and split a token into multiple tokens.
 * This is needed to deal with ambiguity of tokens in the lexer. i.e., in "< ... < ... >>",
 * is the ">>" an operator or two GREATERs?
 * See issue#177 for more context
 *)
let splitToken (token, s, e) =
  match token with
  | GREATERGREATER ->
    [(GREATER, s, e); (GREATER, s, e)]
  | _ ->
    [(token, s, e)]

(* The table of keywords *)

let keyword_table =
  create_hashtable 149 [
    "and", AND;
    "as", AS;
    "assert", ASSERT;
    "begin", BEGIN;
    "class", CLASS;
    "constraint", CONSTRAINT;
    "do", DO;
    "done", DONE;
    "downto", DOWNTO;
    "else", ELSE;
    "end", END;
    "exception", EXCEPTION;
    "external", EXTERNAL;
    "false", FALSE;
    "for", FOR;
    "fun", FUN;
    "function", FUNCTION;
    "functor", FUNCTOR;
    "if", IF;
    "in", IN;
    "include", INCLUDE;
    "inherit", INHERIT;
    "initializer", INITIALIZER;
    "lazy", LAZY;
    "let", LET;
    "switch", SWITCH;
    "match", MATCH; (* Including MATCH for source transforming compat *)
    "method", METHOD;
    "module", MODULE;
    "mutable", MUTABLE;
    "new", NEW;
    "nonrec", NONREC;
    "object", OBJECT;
    "of", OF;
    "open", OPEN;
    "or", OR;
(*  "parser", PARSER; *)
    "private", PRIVATE;
    "rec", REC;
    "sig", SIG;
    "struct", STRUCT;
    "then", THEN;
    "to", TO;
    "true", TRUE;
    "try", TRY;
    "type", TYPE;
    "val", VAL;
    "virtual", VIRTUAL;
    "when", WHEN;
    "while", WHILE;
    "with", WITH;

    "mod", INFIXOP3("mod");
    "land", INFIXOP3("land");
    "lor", INFIXOP3("lor");
    "lxor", INFIXOP3("lxor");
    "lsl", INFIXOP4("lsl");
    "lsr", INFIXOP4("lsr");
    "asr", INFIXOP4("asr")
]

(* To buffer string literals *)

let initial_string_buffer = Bytes.create 256
let string_buff = ref initial_string_buffer
let string_index = ref 0

let reset_string_buffer () =
  string_buff := initial_string_buffer;
  string_index := 0

let store_string_char c =
  if !string_index >= Bytes.length !string_buff then begin
    let new_buff = Bytes.create (Bytes.length (!string_buff) * 2) in
    Bytes.blit !string_buff 0 new_buff 0 (Bytes.length !string_buff);
    string_buff := new_buff
  end;
  Bytes.unsafe_set !string_buff !string_index c;
  incr string_index

let store_string s =
  for i = 0 to String.length s - 1 do
    store_string_char s.[i];
  done

let store_lexeme lexbuf =
  store_string (Lexing.lexeme lexbuf)

let get_stored_string () =
  let s = Bytes.sub_string !string_buff 0 !string_index in
  string_buff := initial_string_buffer;
  s

(* To store the position of the beginning of a string and comment *)
let string_start_loc = ref Location.none;;
let comment_start_loc = ref [];;
let in_comment () = !comment_start_loc <> [];;
let is_in_string = ref false
let in_string () = !is_in_string
let print_warnings = ref true

(* To translate escape sequences *)

let char_for_backslash = function
  | 'n' -> '\010'
  | 'r' -> '\013'
  | 'b' -> '\008'
  | 't' -> '\009'
  | c   -> c

let char_for_decimal_code lexbuf i =
  let c = 100 * (Char.code(Lexing.lexeme_char lexbuf i) - 48) +
           10 * (Char.code(Lexing.lexeme_char lexbuf (i+1)) - 48) +
                (Char.code(Lexing.lexeme_char lexbuf (i+2)) - 48) in
  if (c < 0 || c > 255) then
    if in_comment ()
    then 'x'
    else raise (Error(Illegal_escape (Lexing.lexeme lexbuf),
                      Location.curr lexbuf))
  else Char.chr c

let char_for_hexadecimal_code lexbuf i =
  let d1 = Char.code (Lexing.lexeme_char lexbuf i) in
  let val1 = if d1 >= 97 then d1 - 87
             else if d1 >= 65 then d1 - 55
             else d1 - 48
  in
  let d2 = Char.code (Lexing.lexeme_char lexbuf (i+1)) in
  let val2 = if d2 >= 97 then d2 - 87
             else if d2 >= 65 then d2 - 55
             else d2 - 48
  in
  Char.chr (val1 * 16 + val2)

(* To convert integer literals, allowing max_int + 1 (PR#4210) *)

let cvt_int_literal s =
  - int_of_string ("-" ^ s)
let cvt_int32_literal s =
  Int32.neg (Int32.of_string ("-" ^ String.sub s 0 (String.length s - 1)))
let cvt_int64_literal s =
  Int64.neg (Int64.of_string ("-" ^ String.sub s 0 (String.length s - 1)))
let cvt_nativeint_literal s =
  Nativeint.neg (Nativeint.of_string ("-" ^ String.sub s 0
                                                       (String.length s - 1)))

(* Remove underscores from float literals *)

let remove_underscores s =
  let l = String.length s in
  let b = Bytes.create l in
  let rec remove src dst =
    if src >= l then
      if dst >= l then s else Bytes.sub_string b 0 dst
    else
      match s.[src] with
        '_' -> remove (src + 1) dst
      |  c  -> Bytes.set b dst c; remove (src + 1) (dst + 1)
  in remove 0 0

(* Update the current location with file name and line number. *)

let update_loc lexbuf file line absolute chars =
  let pos = lexbuf.lex_curr_p in
  let new_file = match file with
                 | None -> pos.pos_fname
                 | Some s -> s
  in
  lexbuf.lex_curr_p <- { pos with
    pos_fname = new_file;
    pos_lnum = if absolute then line else pos.pos_lnum + line;
    pos_bol = pos.pos_cnum - chars;
  }
;;

let preprocessor = ref None

(* Warn about Latin-1 characters used in idents *)

let warn_latin1 lexbuf =
  Location.prerr_warning (Location.curr lexbuf)
    (Warnings.Deprecated "ISO-Latin1 characters in identifiers")
;;

(* Error report *)

open Format

let report_error ppf = function
  | Illegal_character c ->
      fprintf ppf "Illegal character (%s)" (Char.escaped c)
  | Illegal_escape s ->
      fprintf ppf "Illegal backslash escape in string or character (%s)" s
  | Unterminated_comment _ ->
      fprintf ppf "Comment not terminated"
  | Unterminated_string ->
      fprintf ppf "String literal not terminated"
  | Unterminated_string_in_comment (_, loc) ->
      fprintf ppf "This comment contains an unterminated string literal@.\
                   %aString literal begins here"
              Location.print_error loc
  | Keyword_as_label kwd ->
      fprintf ppf "`%s' is a keyword, it cannot be used as label name" kwd
  | Literal_overflow ty ->
      fprintf ppf "Integer literal exceeds the range of representable \
                   integers of type %s" ty

let () =
  Location.register_error_of_exn
    (function
      | Error (err, loc) ->
          Some (Location.error_of_printer loc report_error err)
      | _ ->
          None
    )

# 253 "src/reason_lexer.ml"
let __ocaml_lex_tables = {
  Lexing.lex_base = 
   "\000\000\156\255\157\255\224\000\235\000\018\001\053\001\088\001\
    \188\255\123\001\158\001\196\255\091\000\225\001\068\000\083\000\
    \061\002\218\255\220\255\221\255\223\255\072\002\156\002\191\002\
    \226\002\008\001\000\003\238\255\077\003\110\003\183\003\135\004\
    \087\005\039\006\072\000\006\007\017\007\056\007\118\007\126\000\
    \254\255\001\000\108\008\121\008\158\008\193\008\228\008\007\009\
    \042\009\255\255\005\000\089\000\077\009\112\009\147\009\090\000\
    \182\009\097\000\217\009\098\000\252\009\099\000\100\000\101\000\
    \107\000\006\000\110\000\031\010\066\010\208\255\209\255\087\000\
    \248\255\239\255\240\255\241\255\116\000\089\002\114\000\126\000\
    \176\001\002\004\210\004\159\001\120\002\134\000\194\255\237\255\
    \224\002\113\010\117\000\121\000\007\000\236\255\235\255\231\255\
    \224\004\243\002\208\000\234\255\253\002\219\000\233\255\162\005\
    \220\000\232\255\138\010\216\000\229\255\228\255\153\006\217\005\
    \179\010\247\000\226\255\011\000\010\001\096\001\179\001\062\001\
    \226\255\012\000\214\010\249\010\028\011\218\000\212\255\206\255\
    \063\011\098\011\179\007\128\011\218\011\170\255\251\011\197\255\
    \085\012\096\012\228\000\202\000\199\255\200\255\201\255\211\000\
    \182\255\184\255\191\255\135\012\187\255\170\012\205\012\240\012\
    \019\013\054\013\002\001\178\006\243\255\244\255\013\000\245\255\
    \161\001\052\013\253\255\236\000\248\000\255\255\254\255\252\255\
    \084\013\175\013\252\000\253\000\017\000\251\255\250\255\249\255\
    \209\013\087\003\006\001\248\255\031\004\007\001\247\255\248\013\
    \009\001\246\255\018\000\163\001\247\255\248\255\249\255\040\001\
    \063\014\255\255\250\255\097\014\247\004\253\255\056\001\056\001\
    \057\001\002\005\252\255\136\014\251\255\064\001\157\001\252\255\
    \144\014\254\255\255\255\074\001\091\001\253\255\173\014\017\001\
    \024\001\092\001\112\001\025\001\113\001\024\001\019\000\255\255\
    ";
  Lexing.lex_backtrk = 
   "\255\255\255\255\255\255\094\000\090\000\089\000\079\000\074\000\
    \255\255\065\000\062\000\255\255\053\000\050\000\048\000\041\000\
    \082\000\255\255\255\255\255\255\255\255\030\000\040\000\036\000\
    \096\000\033\000\060\000\255\255\012\000\012\000\011\000\010\000\
    \009\000\008\000\044\000\052\000\005\000\004\000\003\000\002\000\
    \255\255\099\000\099\000\097\000\096\000\095\000\091\000\255\255\
    \255\255\255\255\255\255\255\255\087\000\077\000\078\000\255\255\
    \088\000\255\255\095\000\255\255\093\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\039\000\006\000\255\255\255\255\045\000\
    \255\255\255\255\255\255\255\255\255\255\013\000\255\255\255\255\
    \255\255\012\000\012\000\012\000\013\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \024\000\024\000\024\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\092\000\025\000\255\255\255\255\255\255\255\255\
    \028\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\031\000\083\000\038\000\042\000\255\255\255\255\
    \089\000\084\000\255\255\057\000\051\000\255\255\255\255\255\255\
    \089\000\086\000\070\000\069\000\255\255\255\255\255\255\072\000\
    \255\255\255\255\255\255\063\000\255\255\066\000\075\000\076\000\
    \081\000\080\000\255\255\255\255\255\255\255\255\012\000\255\255\
    \012\000\012\000\255\255\012\000\012\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\008\000\
    \008\000\255\255\255\255\005\000\005\000\255\255\001\000\005\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \003\000\255\255\255\255\003\000\255\255\255\255\255\255\002\000\
    \255\255\255\255\001\000\255\255\255\255\255\255\255\255\255\255\
    ";
  Lexing.lex_default = 
   "\001\000\000\000\000\000\255\255\255\255\255\255\255\255\255\255\
    \000\000\255\255\255\255\000\000\255\255\255\255\255\255\255\255\
    \255\255\000\000\000\000\000\000\000\000\255\255\255\255\255\255\
    \255\255\090\000\255\255\000\000\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \000\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\000\000\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\000\000\000\000\255\255\
    \000\000\000\000\000\000\000\000\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\000\000\000\000\
    \255\255\095\000\255\255\255\255\255\255\000\000\000\000\000\000\
    \255\255\255\255\255\255\000\000\255\255\255\255\000\000\255\255\
    \255\255\000\000\255\255\255\255\000\000\000\000\116\000\255\255\
    \255\255\255\255\000\000\255\255\116\000\117\000\116\000\119\000\
    \000\000\255\255\255\255\255\255\255\255\255\255\000\000\000\000\
    \255\255\255\255\255\255\255\255\255\255\000\000\255\255\000\000\
    \255\255\255\255\255\255\255\255\000\000\000\000\000\000\255\255\
    \000\000\000\000\000\000\255\255\000\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\156\000\000\000\000\000\255\255\000\000\
    \170\000\255\255\000\000\255\255\255\255\000\000\000\000\000\000\
    \255\255\255\255\255\255\255\255\255\255\000\000\000\000\000\000\
    \255\255\255\255\255\255\000\000\255\255\255\255\000\000\255\255\
    \255\255\000\000\255\255\188\000\000\000\000\000\000\000\255\255\
    \194\000\000\000\000\000\255\255\255\255\000\000\255\255\255\255\
    \255\255\255\255\000\000\255\255\000\000\255\255\207\000\000\000\
    \255\255\000\000\000\000\255\255\255\255\000\000\255\255\255\255\
    \255\255\217\000\220\000\255\255\220\000\255\255\255\255\000\000\
    ";
  Lexing.lex_trans = 
   "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\039\000\040\000\040\000\039\000\041\000\065\000\049\000\
    \040\000\091\000\050\000\065\000\092\000\114\000\120\000\157\000\
    \115\000\121\000\186\000\171\000\157\000\223\000\172\000\186\000\
    \039\000\007\000\027\000\022\000\005\000\003\000\021\000\025\000\
    \019\000\018\000\023\000\006\000\017\000\016\000\015\000\024\000\
    \029\000\028\000\028\000\028\000\028\000\028\000\028\000\028\000\
    \028\000\028\000\034\000\014\000\013\000\035\000\009\000\036\000\
    \004\000\031\000\031\000\031\000\031\000\031\000\031\000\031\000\
    \031\000\031\000\031\000\031\000\031\000\031\000\031\000\031\000\
    \031\000\031\000\031\000\031\000\031\000\031\000\031\000\031\000\
    \031\000\031\000\031\000\012\000\042\000\011\000\004\000\038\000\
    \020\000\033\000\033\000\033\000\033\000\033\000\033\000\033\000\
    \033\000\033\000\033\000\033\000\033\000\033\000\033\000\033\000\
    \033\000\033\000\033\000\033\000\033\000\033\000\033\000\033\000\
    \033\000\033\000\033\000\026\000\010\000\008\000\037\000\127\000\
    \138\000\125\000\071\000\052\000\056\000\070\000\069\000\039\000\
    \052\000\056\000\039\000\046\000\060\000\060\000\058\000\044\000\
    \046\000\058\000\060\000\058\000\044\000\043\000\072\000\141\000\
    \005\000\140\000\043\000\139\000\094\000\005\000\039\000\085\000\
    \093\000\085\000\083\000\083\000\084\000\084\000\084\000\084\000\
    \084\000\084\000\084\000\084\000\084\000\084\000\082\000\082\000\
    \082\000\082\000\082\000\082\000\082\000\082\000\084\000\084\000\
    \084\000\084\000\084\000\084\000\084\000\084\000\084\000\084\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\030\000\030\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\030\000\030\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\030\000\142\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\030\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\099\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \002\000\043\000\102\000\105\000\043\000\043\000\043\000\108\000\
    \126\000\145\000\143\000\043\000\004\000\043\000\043\000\004\000\
    \004\000\004\000\091\000\144\000\114\000\092\000\004\000\115\000\
    \004\000\004\000\043\000\166\000\043\000\043\000\043\000\043\000\
    \043\000\112\000\165\000\175\000\174\000\004\000\112\000\004\000\
    \004\000\004\000\004\000\004\000\004\000\179\000\182\000\255\255\
    \185\000\004\000\190\000\005\000\216\000\205\000\005\000\005\000\
    \005\000\217\000\221\000\222\000\064\000\005\000\043\000\005\000\
    \005\000\198\000\198\000\198\000\000\000\200\000\200\000\154\000\
    \120\000\004\000\190\000\121\000\005\000\205\000\005\000\005\000\
    \005\000\005\000\005\000\000\000\210\000\000\000\046\000\212\000\
    \198\000\046\000\046\000\046\000\043\000\000\000\043\000\000\000\
    \046\000\000\000\046\000\153\000\089\000\210\000\218\000\004\000\
    \212\000\004\000\114\000\000\000\000\000\115\000\066\000\046\000\
    \005\000\046\000\152\000\046\000\046\000\046\000\000\000\000\000\
    \000\000\052\000\219\000\219\000\052\000\052\000\052\000\000\000\
    \000\000\000\000\119\000\052\000\000\000\052\000\052\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\005\000\000\000\
    \005\000\057\000\052\000\046\000\052\000\150\000\052\000\052\000\
    \052\000\000\000\000\000\000\000\005\000\000\000\000\000\005\000\
    \005\000\005\000\000\000\000\000\000\000\000\000\005\000\210\000\
    \005\000\005\000\211\000\171\000\000\000\190\000\172\000\000\000\
    \191\000\046\000\000\000\046\000\051\000\005\000\052\000\005\000\
    \005\000\149\000\005\000\005\000\118\000\114\000\000\000\005\000\
    \115\000\000\000\005\000\005\000\005\000\193\000\000\000\000\000\
    \173\000\005\000\000\000\005\000\005\000\000\000\000\000\083\000\
    \083\000\000\000\000\000\118\000\052\000\117\000\052\000\066\000\
    \005\000\005\000\005\000\005\000\005\000\005\000\005\000\000\000\
    \081\000\081\000\081\000\081\000\081\000\081\000\081\000\081\000\
    \081\000\081\000\000\000\074\000\000\000\000\000\000\000\000\000\
    \000\000\081\000\081\000\081\000\081\000\081\000\081\000\005\000\
    \148\000\005\000\066\000\146\000\005\000\169\000\083\000\192\000\
    \000\000\000\000\005\000\000\000\000\000\005\000\005\000\005\000\
    \255\255\000\000\255\255\075\000\005\000\073\000\132\000\128\000\
    \130\000\081\000\081\000\081\000\081\000\081\000\081\000\000\000\
    \000\000\208\000\147\000\005\000\005\000\005\000\005\000\129\000\
    \005\000\005\000\131\000\131\000\131\000\131\000\131\000\131\000\
    \131\000\131\000\131\000\131\000\131\000\131\000\131\000\131\000\
    \131\000\131\000\131\000\131\000\131\000\131\000\131\000\131\000\
    \131\000\131\000\131\000\131\000\000\000\066\000\255\255\005\000\
    \131\000\000\000\131\000\131\000\131\000\131\000\131\000\131\000\
    \131\000\131\000\131\000\131\000\131\000\131\000\131\000\131\000\
    \131\000\131\000\131\000\131\000\131\000\131\000\131\000\131\000\
    \131\000\131\000\131\000\131\000\255\255\005\000\046\000\005\000\
    \255\255\046\000\046\000\046\000\000\000\000\000\000\000\000\000\
    \046\000\005\000\046\000\123\000\005\000\005\000\122\000\000\000\
    \255\255\255\255\000\000\005\000\000\000\005\000\005\000\046\000\
    \000\000\046\000\046\000\124\000\046\000\046\000\000\000\000\000\
    \000\000\000\000\005\000\000\000\005\000\005\000\005\000\005\000\
    \005\000\077\000\077\000\077\000\077\000\077\000\077\000\077\000\
    \077\000\077\000\077\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\057\000\000\000\046\000\000\000\209\000\076\000\000\000\
    \000\000\255\255\000\000\189\000\066\000\111\000\005\000\000\000\
    \084\000\084\000\084\000\084\000\084\000\084\000\084\000\084\000\
    \084\000\084\000\000\000\255\255\000\000\000\000\000\000\000\000\
    \077\000\046\000\000\000\046\000\111\000\112\000\076\000\112\000\
    \112\000\112\000\112\000\000\000\005\000\000\000\005\000\112\000\
    \000\000\112\000\112\000\000\000\110\000\110\000\110\000\110\000\
    \110\000\110\000\110\000\110\000\110\000\110\000\112\000\084\000\
    \112\000\112\000\112\000\112\000\112\000\000\000\000\000\000\000\
    \058\000\000\000\000\000\058\000\058\000\058\000\000\000\000\000\
    \000\000\000\000\058\000\000\000\058\000\058\000\109\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \113\000\058\000\112\000\058\000\058\000\058\000\058\000\058\000\
    \000\000\000\000\000\000\044\000\000\000\000\000\044\000\044\000\
    \044\000\000\000\000\000\000\000\107\000\044\000\000\000\044\000\
    \044\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \112\000\000\000\112\000\059\000\044\000\058\000\044\000\044\000\
    \106\000\044\000\044\000\100\000\100\000\100\000\100\000\100\000\
    \100\000\100\000\100\000\100\000\100\000\101\000\101\000\101\000\
    \101\000\101\000\101\000\101\000\101\000\101\000\101\000\000\000\
    \000\000\000\000\000\000\058\000\086\000\058\000\063\000\088\000\
    \044\000\088\000\088\000\088\000\088\000\088\000\088\000\088\000\
    \088\000\088\000\088\000\088\000\088\000\088\000\088\000\088\000\
    \088\000\088\000\088\000\088\000\088\000\088\000\088\000\088\000\
    \088\000\088\000\088\000\000\000\087\000\000\000\044\000\088\000\
    \044\000\088\000\088\000\088\000\088\000\088\000\088\000\088\000\
    \088\000\088\000\088\000\088\000\088\000\088\000\088\000\088\000\
    \088\000\088\000\088\000\088\000\088\000\088\000\088\000\088\000\
    \088\000\088\000\088\000\077\000\087\000\028\000\028\000\028\000\
    \028\000\028\000\028\000\028\000\028\000\028\000\028\000\180\000\
    \180\000\180\000\180\000\180\000\180\000\180\000\180\000\180\000\
    \180\000\000\000\076\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\074\000\000\000\000\000\077\000\000\000\028\000\028\000\
    \028\000\028\000\028\000\028\000\028\000\028\000\028\000\028\000\
    \000\000\000\000\000\000\000\000\028\000\000\000\000\000\000\000\
    \078\000\000\000\076\000\076\000\000\000\000\000\000\000\000\000\
    \000\000\075\000\074\000\073\000\000\000\079\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\080\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\028\000\000\000\000\000\
    \078\000\000\000\000\000\076\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\075\000\000\000\073\000\079\000\030\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\080\000\030\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\030\000\030\000\
    \030\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\030\000\030\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\030\000\030\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\030\000\030\000\
    \030\000\030\000\000\000\000\000\000\000\000\000\030\000\000\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\030\000\030\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\030\000\030\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\030\000\030\000\
    \030\000\030\000\081\000\081\000\081\000\081\000\081\000\081\000\
    \081\000\081\000\081\000\081\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\081\000\081\000\081\000\081\000\081\000\
    \081\000\000\000\000\000\000\000\000\000\000\000\074\000\181\000\
    \181\000\181\000\181\000\181\000\181\000\181\000\181\000\181\000\
    \181\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\081\000\000\000\081\000\081\000\081\000\081\000\081\000\
    \081\000\000\000\000\000\000\000\000\000\000\000\075\000\000\000\
    \073\000\000\000\000\000\000\000\000\000\000\000\000\000\030\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\030\000\030\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\030\000\030\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\000\000\030\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\030\000\030\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\030\000\030\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\030\000\030\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\031\000\030\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\030\000\031\000\
    \031\000\031\000\031\000\031\000\031\000\031\000\031\000\031\000\
    \031\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \031\000\031\000\031\000\031\000\031\000\031\000\031\000\031\000\
    \031\000\031\000\031\000\031\000\031\000\031\000\031\000\031\000\
    \031\000\031\000\031\000\031\000\031\000\031\000\031\000\031\000\
    \031\000\031\000\000\000\000\000\000\000\000\000\031\000\000\000\
    \031\000\031\000\031\000\031\000\031\000\031\000\031\000\031\000\
    \031\000\031\000\031\000\031\000\031\000\031\000\031\000\031\000\
    \031\000\031\000\031\000\031\000\031\000\031\000\031\000\031\000\
    \031\000\031\000\082\000\082\000\082\000\082\000\082\000\082\000\
    \082\000\082\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \103\000\103\000\103\000\103\000\103\000\103\000\103\000\103\000\
    \103\000\103\000\000\000\000\000\000\000\000\000\074\000\000\000\
    \000\000\103\000\103\000\103\000\103\000\103\000\103\000\201\000\
    \201\000\201\000\201\000\201\000\201\000\201\000\201\000\201\000\
    \201\000\082\000\202\000\202\000\202\000\202\000\202\000\202\000\
    \202\000\202\000\202\000\202\000\000\000\000\000\075\000\000\000\
    \073\000\103\000\103\000\103\000\103\000\103\000\103\000\030\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\030\000\030\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\030\000\030\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\000\000\030\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\030\000\030\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\030\000\030\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\030\000\030\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\032\000\030\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\030\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\000\000\000\000\000\000\000\000\032\000\000\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\104\000\104\000\104\000\104\000\104\000\104\000\
    \104\000\104\000\104\000\104\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\111\000\104\000\104\000\104\000\104\000\104\000\
    \104\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\111\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\104\000\104\000\104\000\104\000\104\000\
    \104\000\110\000\110\000\110\000\110\000\110\000\110\000\110\000\
    \110\000\110\000\110\000\000\000\000\000\000\000\000\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\000\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\033\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\033\000\
    \033\000\033\000\033\000\033\000\033\000\033\000\033\000\033\000\
    \033\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \033\000\033\000\033\000\033\000\033\000\033\000\033\000\033\000\
    \033\000\033\000\033\000\033\000\033\000\033\000\033\000\033\000\
    \033\000\033\000\033\000\033\000\033\000\033\000\033\000\033\000\
    \033\000\033\000\000\000\000\000\000\000\000\000\033\000\000\000\
    \033\000\033\000\033\000\033\000\033\000\033\000\033\000\033\000\
    \033\000\033\000\033\000\033\000\033\000\033\000\033\000\033\000\
    \033\000\033\000\033\000\033\000\033\000\033\000\033\000\033\000\
    \033\000\033\000\118\000\114\000\000\000\000\000\115\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\118\000\000\000\117\000\157\000\000\000\000\000\158\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\110\000\110\000\110\000\110\000\110\000\110\000\110\000\
    \110\000\110\000\110\000\000\000\162\000\000\000\000\000\000\000\
    \000\000\160\000\000\000\000\000\163\000\000\000\000\000\000\000\
    \000\000\164\000\000\000\000\000\000\000\000\000\000\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\000\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\000\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\005\000\
    \000\000\000\000\005\000\005\000\005\000\161\000\000\000\000\000\
    \000\000\005\000\056\000\005\000\005\000\056\000\056\000\056\000\
    \000\000\000\000\000\000\000\000\056\000\000\000\056\000\056\000\
    \005\000\000\000\005\000\005\000\067\000\068\000\005\000\000\000\
    \000\000\000\000\000\000\056\000\000\000\056\000\056\000\056\000\
    \056\000\056\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\056\000\000\000\000\000\056\000\056\000\056\000\000\000\
    \000\000\000\000\066\000\056\000\005\000\056\000\056\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\055\000\000\000\056\000\
    \000\000\000\000\056\000\000\000\056\000\056\000\056\000\056\000\
    \056\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\005\000\000\000\005\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\056\000\000\000\056\000\
    \000\000\000\000\000\000\000\000\055\000\000\000\056\000\000\000\
    \000\000\255\255\000\000\000\000\000\000\033\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\033\000\033\000\
    \033\000\033\000\033\000\033\000\033\000\033\000\033\000\033\000\
    \000\000\000\000\159\000\000\000\056\000\000\000\056\000\033\000\
    \033\000\033\000\033\000\033\000\033\000\033\000\033\000\033\000\
    \033\000\033\000\033\000\033\000\033\000\033\000\033\000\033\000\
    \033\000\033\000\033\000\033\000\033\000\033\000\033\000\033\000\
    \033\000\000\000\000\000\000\000\000\000\033\000\000\000\033\000\
    \033\000\033\000\033\000\033\000\033\000\033\000\033\000\033\000\
    \033\000\033\000\033\000\033\000\033\000\033\000\033\000\033\000\
    \033\000\033\000\033\000\033\000\033\000\033\000\033\000\033\000\
    \033\000\133\000\000\000\000\000\134\000\134\000\134\000\134\000\
    \134\000\134\000\134\000\134\000\134\000\134\000\134\000\134\000\
    \134\000\134\000\134\000\134\000\134\000\134\000\134\000\134\000\
    \134\000\134\000\134\000\134\000\134\000\134\000\000\000\000\000\
    \000\000\000\000\134\000\000\000\134\000\134\000\134\000\134\000\
    \134\000\134\000\134\000\134\000\134\000\134\000\134\000\134\000\
    \134\000\134\000\134\000\134\000\134\000\134\000\134\000\134\000\
    \134\000\134\000\134\000\134\000\134\000\134\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\000\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\000\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\049\000\000\000\
    \000\000\050\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\048\000\000\000\000\000\
    \005\000\043\000\005\000\000\000\000\000\000\000\045\000\046\000\
    \000\000\046\000\043\000\044\000\000\000\043\000\043\000\043\000\
    \000\000\000\000\000\000\000\000\043\000\000\000\043\000\043\000\
    \005\000\005\000\005\000\047\000\004\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\043\000\000\000\043\000\043\000\043\000\
    \043\000\043\000\000\000\000\000\000\000\000\000\000\000\044\000\
    \000\000\000\000\044\000\044\000\044\000\000\000\000\000\000\000\
    \000\000\044\000\004\000\044\000\044\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\064\000\000\000\043\000\
    \044\000\000\000\044\000\044\000\044\000\044\000\044\000\000\000\
    \000\000\000\000\058\000\000\000\000\000\058\000\058\000\058\000\
    \005\000\000\000\047\000\000\000\058\000\000\000\058\000\058\000\
    \000\000\000\000\000\000\000\000\000\000\043\000\000\000\043\000\
    \000\000\000\000\063\000\058\000\044\000\058\000\058\000\058\000\
    \058\000\058\000\000\000\000\000\000\000\046\000\000\000\000\000\
    \046\000\046\000\046\000\000\000\000\000\000\000\000\000\046\000\
    \000\000\046\000\046\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\044\000\000\000\044\000\059\000\046\000\058\000\
    \046\000\046\000\046\000\046\000\046\000\000\000\000\000\000\000\
    \056\000\000\000\000\000\056\000\056\000\056\000\000\000\000\000\
    \000\000\000\000\056\000\000\000\056\000\056\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\058\000\000\000\058\000\
    \057\000\056\000\046\000\056\000\056\000\056\000\056\000\056\000\
    \000\000\000\000\000\000\052\000\000\000\000\000\052\000\052\000\
    \052\000\000\000\000\000\000\000\000\000\052\000\000\000\052\000\
    \052\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \046\000\000\000\046\000\055\000\052\000\056\000\052\000\053\000\
    \052\000\052\000\052\000\000\000\000\000\000\000\052\000\000\000\
    \000\000\052\000\052\000\052\000\000\000\000\000\000\000\000\000\
    \052\000\000\000\052\000\052\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\056\000\000\000\056\000\051\000\052\000\
    \052\000\052\000\052\000\052\000\052\000\052\000\000\000\000\000\
    \000\000\052\000\000\000\000\000\052\000\052\000\052\000\000\000\
    \000\000\000\000\000\000\052\000\000\000\052\000\052\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\052\000\000\000\
    \052\000\051\000\052\000\052\000\052\000\054\000\052\000\052\000\
    \052\000\000\000\000\000\000\000\052\000\000\000\000\000\052\000\
    \052\000\052\000\000\000\000\000\000\000\000\000\052\000\000\000\
    \052\000\052\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\052\000\000\000\052\000\051\000\052\000\052\000\052\000\
    \052\000\052\000\052\000\052\000\000\000\000\000\000\000\056\000\
    \000\000\000\000\056\000\056\000\056\000\000\000\000\000\000\000\
    \000\000\056\000\000\000\056\000\056\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\052\000\000\000\052\000\051\000\
    \056\000\052\000\056\000\056\000\056\000\056\000\056\000\000\000\
    \000\000\000\000\058\000\000\000\000\000\058\000\058\000\058\000\
    \000\000\000\000\000\000\000\000\058\000\000\000\058\000\058\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\052\000\
    \000\000\052\000\055\000\058\000\056\000\058\000\058\000\058\000\
    \058\000\058\000\000\000\000\000\000\000\060\000\000\000\000\000\
    \060\000\060\000\060\000\000\000\000\000\000\000\000\000\060\000\
    \000\000\060\000\060\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\056\000\000\000\056\000\062\000\060\000\058\000\
    \060\000\060\000\060\000\060\000\060\000\000\000\000\000\000\000\
    \005\000\000\000\000\000\005\000\005\000\005\000\000\000\000\000\
    \000\000\000\000\005\000\000\000\005\000\005\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\058\000\000\000\058\000\
    \061\000\005\000\060\000\005\000\005\000\005\000\005\000\005\000\
    \000\000\000\000\000\000\005\000\000\000\000\000\005\000\005\000\
    \005\000\000\000\000\000\000\000\000\000\005\000\000\000\005\000\
    \005\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \060\000\000\000\060\000\066\000\005\000\005\000\005\000\005\000\
    \005\000\005\000\005\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\098\000\000\000\098\000\000\000\000\000\000\000\000\000\
    \098\000\000\000\000\000\005\000\000\000\005\000\066\000\000\000\
    \005\000\097\000\097\000\097\000\097\000\097\000\097\000\097\000\
    \097\000\097\000\097\000\044\000\000\000\000\000\044\000\044\000\
    \044\000\000\000\000\000\000\000\000\000\044\000\000\000\044\000\
    \044\000\000\000\000\000\000\000\000\000\000\000\005\000\000\000\
    \005\000\000\000\000\000\000\000\044\000\000\000\044\000\044\000\
    \044\000\044\000\044\000\000\000\000\000\098\000\000\000\000\000\
    \000\000\000\000\000\000\098\000\112\000\000\000\112\000\112\000\
    \112\000\112\000\000\000\000\000\000\000\000\000\112\000\098\000\
    \112\000\112\000\000\000\098\000\000\000\098\000\063\000\000\000\
    \044\000\096\000\000\000\000\000\000\000\112\000\000\000\112\000\
    \112\000\112\000\112\000\112\000\000\000\000\000\000\000\005\000\
    \000\000\000\000\005\000\005\000\005\000\000\000\000\000\000\000\
    \000\000\005\000\000\000\005\000\005\000\000\000\044\000\000\000\
    \044\000\000\000\000\000\000\000\000\000\000\000\000\000\113\000\
    \005\000\112\000\005\000\005\000\005\000\005\000\005\000\000\000\
    \000\000\000\000\046\000\000\000\000\000\046\000\046\000\046\000\
    \000\000\000\000\000\000\000\000\046\000\000\000\046\000\046\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\112\000\
    \000\000\112\000\066\000\046\000\005\000\046\000\046\000\046\000\
    \046\000\046\000\000\000\000\000\000\000\046\000\000\000\000\000\
    \046\000\046\000\046\000\000\000\000\000\000\000\000\000\046\000\
    \000\000\046\000\046\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\005\000\000\000\005\000\057\000\046\000\046\000\
    \046\000\046\000\046\000\046\000\046\000\000\000\000\000\000\000\
    \005\000\000\000\000\000\005\000\005\000\005\000\000\000\000\000\
    \000\000\000\000\005\000\000\000\005\000\136\000\000\000\000\000\
    \000\000\255\255\000\000\000\000\000\000\046\000\000\000\046\000\
    \057\000\005\000\046\000\005\000\005\000\005\000\005\000\005\000\
    \000\000\000\000\000\000\005\000\000\000\000\000\005\000\005\000\
    \005\000\000\000\000\000\000\000\000\000\005\000\000\000\005\000\
    \005\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \046\000\000\000\046\000\066\000\005\000\005\000\005\000\005\000\
    \005\000\005\000\005\000\000\000\000\000\000\000\000\000\131\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\131\000\000\000\
    \131\000\131\000\131\000\131\000\131\000\131\000\131\000\131\000\
    \131\000\131\000\000\000\005\000\000\000\005\000\066\000\000\000\
    \005\000\131\000\131\000\131\000\131\000\131\000\131\000\131\000\
    \131\000\131\000\131\000\131\000\131\000\131\000\131\000\131\000\
    \131\000\131\000\131\000\131\000\131\000\131\000\131\000\131\000\
    \131\000\131\000\131\000\000\000\000\000\000\000\005\000\131\000\
    \005\000\131\000\131\000\131\000\131\000\131\000\131\000\131\000\
    \131\000\131\000\131\000\131\000\131\000\131\000\131\000\131\000\
    \131\000\131\000\131\000\131\000\131\000\131\000\131\000\131\000\
    \131\000\131\000\131\000\005\000\000\000\000\000\005\000\005\000\
    \005\000\000\000\000\000\000\000\000\000\005\000\000\000\005\000\
    \005\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\005\000\000\000\005\000\005\000\
    \005\000\005\000\005\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\134\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\134\000\000\000\134\000\134\000\134\000\134\000\134\000\
    \134\000\134\000\134\000\134\000\134\000\000\000\066\000\000\000\
    \005\000\135\000\000\000\000\000\134\000\134\000\134\000\134\000\
    \134\000\134\000\134\000\134\000\134\000\134\000\134\000\134\000\
    \134\000\134\000\134\000\134\000\134\000\134\000\134\000\134\000\
    \134\000\134\000\134\000\134\000\134\000\134\000\005\000\000\000\
    \005\000\000\000\134\000\000\000\134\000\134\000\134\000\134\000\
    \134\000\134\000\134\000\134\000\134\000\134\000\134\000\134\000\
    \134\000\134\000\134\000\134\000\134\000\134\000\134\000\134\000\
    \134\000\134\000\134\000\134\000\134\000\134\000\005\000\000\000\
    \000\000\005\000\005\000\005\000\000\000\000\000\000\000\000\000\
    \005\000\005\000\005\000\005\000\005\000\005\000\005\000\000\000\
    \000\000\000\000\000\000\005\000\000\000\005\000\005\000\005\000\
    \000\000\005\000\005\000\137\000\005\000\005\000\000\000\000\000\
    \000\000\000\000\005\000\000\000\005\000\005\000\005\000\005\000\
    \005\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \005\000\000\000\000\000\005\000\005\000\005\000\000\000\000\000\
    \000\000\066\000\005\000\005\000\005\000\005\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\066\000\000\000\005\000\000\000\
    \000\000\005\000\000\000\005\000\005\000\005\000\005\000\005\000\
    \000\000\000\000\000\000\005\000\000\000\000\000\005\000\005\000\
    \005\000\005\000\000\000\005\000\000\000\005\000\000\000\005\000\
    \005\000\000\000\000\000\000\000\005\000\000\000\005\000\000\000\
    \000\000\000\000\000\000\066\000\005\000\005\000\005\000\005\000\
    \005\000\005\000\005\000\000\000\000\000\000\000\052\000\000\000\
    \000\000\052\000\052\000\052\000\000\000\000\000\000\000\000\000\
    \052\000\000\000\052\000\052\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\005\000\000\000\005\000\066\000\052\000\
    \005\000\052\000\151\000\052\000\052\000\052\000\000\000\000\000\
    \000\000\052\000\000\000\000\000\052\000\052\000\052\000\000\000\
    \000\000\000\000\000\000\052\000\000\000\052\000\052\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\005\000\000\000\
    \005\000\051\000\052\000\052\000\052\000\052\000\052\000\052\000\
    \052\000\000\000\000\000\000\000\046\000\000\000\000\000\046\000\
    \046\000\046\000\000\000\000\000\000\000\000\000\046\000\000\000\
    \046\000\046\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\052\000\000\000\052\000\051\000\046\000\052\000\046\000\
    \046\000\046\000\046\000\046\000\000\000\000\000\000\000\046\000\
    \000\000\000\000\046\000\046\000\046\000\000\000\000\000\000\000\
    \000\000\046\000\000\000\046\000\046\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\052\000\000\000\052\000\057\000\
    \046\000\046\000\046\000\046\000\046\000\046\000\046\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\046\000\
    \000\000\046\000\057\000\168\000\046\000\168\000\168\000\168\000\
    \168\000\168\000\168\000\168\000\168\000\168\000\168\000\168\000\
    \168\000\168\000\168\000\168\000\168\000\168\000\168\000\168\000\
    \168\000\168\000\168\000\168\000\168\000\168\000\168\000\000\000\
    \167\000\000\000\046\000\168\000\046\000\168\000\168\000\168\000\
    \168\000\168\000\168\000\168\000\168\000\168\000\168\000\168\000\
    \168\000\168\000\168\000\168\000\168\000\168\000\168\000\168\000\
    \168\000\168\000\168\000\168\000\168\000\168\000\168\000\178\000\
    \167\000\178\000\000\000\000\000\000\000\000\000\178\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\177\000\
    \177\000\177\000\177\000\177\000\177\000\177\000\177\000\177\000\
    \177\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\183\000\183\000\183\000\183\000\183\000\183\000\183\000\
    \183\000\183\000\183\000\178\000\000\000\000\000\000\000\000\000\
    \000\000\178\000\183\000\183\000\183\000\183\000\183\000\183\000\
    \000\000\000\000\000\000\000\000\000\000\178\000\000\000\000\000\
    \000\000\178\000\000\000\178\000\000\000\000\000\000\000\176\000\
    \184\000\184\000\184\000\184\000\184\000\184\000\184\000\184\000\
    \184\000\184\000\183\000\183\000\183\000\183\000\183\000\183\000\
    \000\000\184\000\184\000\184\000\184\000\184\000\184\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\198\000\000\000\000\000\199\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\184\000\184\000\184\000\184\000\184\000\184\000\197\000\
    \000\000\197\000\000\000\000\000\000\000\000\000\197\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\196\000\
    \196\000\196\000\196\000\196\000\196\000\196\000\196\000\196\000\
    \196\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\203\000\203\000\203\000\203\000\203\000\203\000\203\000\
    \203\000\203\000\203\000\197\000\000\000\000\000\000\000\000\000\
    \000\000\197\000\203\000\203\000\203\000\203\000\203\000\203\000\
    \000\000\000\000\000\000\000\000\000\000\197\000\000\000\000\000\
    \000\000\197\000\000\000\197\000\000\000\000\000\000\000\195\000\
    \204\000\204\000\204\000\204\000\204\000\204\000\204\000\204\000\
    \204\000\204\000\203\000\203\000\203\000\203\000\203\000\203\000\
    \000\000\204\000\204\000\204\000\204\000\204\000\204\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\204\000\204\000\204\000\204\000\204\000\204\000\214\000\
    \000\000\214\000\214\000\214\000\214\000\214\000\214\000\214\000\
    \214\000\214\000\214\000\214\000\214\000\214\000\214\000\214\000\
    \214\000\214\000\214\000\214\000\214\000\214\000\214\000\214\000\
    \214\000\214\000\214\000\000\000\214\000\213\000\214\000\214\000\
    \214\000\214\000\214\000\214\000\214\000\214\000\214\000\214\000\
    \214\000\214\000\214\000\214\000\214\000\214\000\214\000\214\000\
    \214\000\214\000\214\000\214\000\214\000\214\000\214\000\214\000\
    \000\000\000\000\213\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\255\255\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000";
  Lexing.lex_check = 
   "\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\000\000\000\000\041\000\000\000\000\000\041\000\050\000\
    \065\000\092\000\050\000\065\000\092\000\115\000\121\000\158\000\
    \115\000\121\000\158\000\172\000\186\000\222\000\172\000\186\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\014\000\
    \012\000\015\000\034\000\051\000\055\000\034\000\034\000\039\000\
    \051\000\055\000\039\000\057\000\059\000\061\000\062\000\063\000\
    \057\000\059\000\061\000\062\000\063\000\064\000\071\000\012\000\
    \066\000\012\000\064\000\012\000\090\000\066\000\039\000\076\000\
    \091\000\076\000\078\000\078\000\076\000\076\000\076\000\076\000\
    \076\000\076\000\076\000\076\000\076\000\076\000\079\000\079\000\
    \079\000\079\000\079\000\079\000\079\000\079\000\085\000\085\000\
    \085\000\085\000\085\000\085\000\085\000\085\000\085\000\085\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\012\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\098\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\003\000\101\000\104\000\003\000\003\000\003\000\107\000\
    \125\000\138\000\139\000\003\000\004\000\003\000\003\000\004\000\
    \004\000\004\000\025\000\143\000\116\000\025\000\004\000\116\000\
    \004\000\004\000\003\000\163\000\003\000\003\000\003\000\003\000\
    \003\000\113\000\164\000\170\000\171\000\004\000\113\000\004\000\
    \004\000\004\000\004\000\004\000\154\000\178\000\181\000\025\000\
    \184\000\154\000\191\000\005\000\215\000\191\000\005\000\005\000\
    \005\000\216\000\219\000\221\000\003\000\005\000\003\000\005\000\
    \005\000\198\000\199\000\200\000\255\255\199\000\200\000\004\000\
    \119\000\004\000\205\000\119\000\005\000\205\000\005\000\005\000\
    \005\000\005\000\005\000\255\255\211\000\255\255\006\000\211\000\
    \198\000\006\000\006\000\006\000\003\000\255\255\003\000\255\255\
    \006\000\255\255\006\000\006\000\025\000\212\000\217\000\004\000\
    \212\000\004\000\117\000\255\255\255\255\117\000\005\000\006\000\
    \005\000\006\000\006\000\006\000\006\000\006\000\255\255\255\255\
    \255\255\007\000\218\000\220\000\007\000\007\000\007\000\255\255\
    \255\255\255\255\117\000\007\000\255\255\007\000\007\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\005\000\255\255\
    \005\000\006\000\007\000\006\000\007\000\007\000\007\000\007\000\
    \007\000\255\255\255\255\255\255\009\000\255\255\255\255\009\000\
    \009\000\009\000\255\255\255\255\255\255\255\255\009\000\206\000\
    \009\000\009\000\206\000\160\000\255\255\187\000\160\000\255\255\
    \187\000\006\000\255\255\006\000\007\000\009\000\007\000\009\000\
    \009\000\009\000\009\000\009\000\118\000\118\000\255\255\010\000\
    \118\000\255\255\010\000\010\000\010\000\187\000\255\255\255\255\
    \160\000\010\000\255\255\010\000\010\000\255\255\255\255\083\000\
    \083\000\255\255\255\255\118\000\007\000\118\000\007\000\009\000\
    \010\000\009\000\010\000\010\000\010\000\010\000\010\000\255\255\
    \080\000\080\000\080\000\080\000\080\000\080\000\080\000\080\000\
    \080\000\080\000\255\255\083\000\255\255\255\255\255\255\255\255\
    \255\255\080\000\080\000\080\000\080\000\080\000\080\000\009\000\
    \009\000\009\000\010\000\010\000\010\000\160\000\083\000\187\000\
    \255\255\255\255\013\000\255\255\255\255\013\000\013\000\013\000\
    \025\000\255\255\116\000\083\000\013\000\083\000\013\000\013\000\
    \013\000\080\000\080\000\080\000\080\000\080\000\080\000\255\255\
    \255\255\206\000\010\000\013\000\010\000\013\000\013\000\013\000\
    \013\000\013\000\013\000\013\000\013\000\013\000\013\000\013\000\
    \013\000\013\000\013\000\013\000\013\000\013\000\013\000\013\000\
    \013\000\013\000\013\000\013\000\013\000\013\000\013\000\013\000\
    \013\000\013\000\013\000\013\000\255\255\013\000\119\000\013\000\
    \013\000\255\255\013\000\013\000\013\000\013\000\013\000\013\000\
    \013\000\013\000\013\000\013\000\013\000\013\000\013\000\013\000\
    \013\000\013\000\013\000\013\000\013\000\013\000\013\000\013\000\
    \013\000\013\000\013\000\013\000\217\000\013\000\016\000\013\000\
    \117\000\016\000\016\000\016\000\255\255\255\255\255\255\255\255\
    \016\000\021\000\016\000\016\000\021\000\021\000\021\000\255\255\
    \218\000\220\000\255\255\021\000\255\255\021\000\021\000\016\000\
    \255\255\016\000\016\000\016\000\016\000\016\000\255\255\255\255\
    \255\255\255\255\021\000\255\255\021\000\021\000\021\000\021\000\
    \021\000\077\000\077\000\077\000\077\000\077\000\077\000\077\000\
    \077\000\077\000\077\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\016\000\255\255\016\000\255\255\206\000\077\000\255\255\
    \255\255\160\000\255\255\187\000\021\000\022\000\021\000\255\255\
    \084\000\084\000\084\000\084\000\084\000\084\000\084\000\084\000\
    \084\000\084\000\255\255\118\000\255\255\255\255\255\255\255\255\
    \077\000\016\000\255\255\016\000\022\000\022\000\077\000\022\000\
    \022\000\022\000\022\000\255\255\021\000\255\255\021\000\022\000\
    \255\255\022\000\022\000\255\255\022\000\022\000\022\000\022\000\
    \022\000\022\000\022\000\022\000\022\000\022\000\022\000\084\000\
    \022\000\022\000\022\000\022\000\022\000\255\255\255\255\255\255\
    \023\000\255\255\255\255\023\000\023\000\023\000\255\255\255\255\
    \255\255\255\255\023\000\255\255\023\000\023\000\023\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \022\000\023\000\022\000\023\000\023\000\023\000\023\000\023\000\
    \255\255\255\255\255\255\024\000\255\255\255\255\024\000\024\000\
    \024\000\255\255\255\255\255\255\024\000\024\000\255\255\024\000\
    \024\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \022\000\255\255\022\000\023\000\024\000\023\000\024\000\024\000\
    \024\000\024\000\024\000\097\000\097\000\097\000\097\000\097\000\
    \097\000\097\000\097\000\097\000\097\000\100\000\100\000\100\000\
    \100\000\100\000\100\000\100\000\100\000\100\000\100\000\255\255\
    \255\255\255\255\255\255\023\000\026\000\023\000\024\000\088\000\
    \024\000\088\000\088\000\088\000\088\000\088\000\088\000\088\000\
    \088\000\088\000\088\000\088\000\088\000\088\000\088\000\088\000\
    \088\000\088\000\088\000\088\000\088\000\088\000\088\000\088\000\
    \088\000\088\000\088\000\255\255\088\000\255\255\024\000\026\000\
    \024\000\026\000\026\000\026\000\026\000\026\000\026\000\026\000\
    \026\000\026\000\026\000\026\000\026\000\026\000\026\000\026\000\
    \026\000\026\000\026\000\026\000\026\000\026\000\026\000\026\000\
    \026\000\026\000\026\000\028\000\026\000\028\000\028\000\028\000\
    \028\000\028\000\028\000\028\000\028\000\028\000\028\000\177\000\
    \177\000\177\000\177\000\177\000\177\000\177\000\177\000\177\000\
    \177\000\255\255\028\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\028\000\255\255\255\255\029\000\255\255\029\000\029\000\
    \029\000\029\000\029\000\029\000\029\000\029\000\029\000\029\000\
    \255\255\255\255\255\255\255\255\028\000\255\255\255\255\255\255\
    \029\000\255\255\028\000\029\000\255\255\255\255\255\255\255\255\
    \255\255\028\000\029\000\028\000\255\255\029\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\029\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\029\000\255\255\255\255\
    \029\000\255\255\255\255\029\000\255\255\255\255\255\255\255\255\
    \255\255\255\255\029\000\255\255\029\000\029\000\030\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\029\000\030\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\030\000\030\000\
    \030\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \030\000\030\000\030\000\030\000\030\000\030\000\030\000\030\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\030\000\030\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\030\000\030\000\
    \030\000\030\000\255\255\255\255\255\255\255\255\030\000\255\255\
    \030\000\030\000\030\000\030\000\030\000\030\000\030\000\030\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\030\000\030\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\030\000\030\000\
    \030\000\030\000\081\000\081\000\081\000\081\000\081\000\081\000\
    \081\000\081\000\081\000\081\000\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\081\000\081\000\081\000\081\000\081\000\
    \081\000\255\255\255\255\255\255\255\255\255\255\081\000\180\000\
    \180\000\180\000\180\000\180\000\180\000\180\000\180\000\180\000\
    \180\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\081\000\255\255\081\000\081\000\081\000\081\000\081\000\
    \081\000\255\255\255\255\255\255\255\255\255\255\081\000\255\255\
    \081\000\255\255\255\255\255\255\255\255\255\255\255\255\030\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\030\000\030\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\030\000\030\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\255\255\030\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\030\000\030\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\030\000\030\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\030\000\030\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\031\000\030\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\030\000\031\000\
    \031\000\031\000\031\000\031\000\031\000\031\000\031\000\031\000\
    \031\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \031\000\031\000\031\000\031\000\031\000\031\000\031\000\031\000\
    \031\000\031\000\031\000\031\000\031\000\031\000\031\000\031\000\
    \031\000\031\000\031\000\031\000\031\000\031\000\031\000\031\000\
    \031\000\031\000\255\255\255\255\255\255\255\255\031\000\255\255\
    \031\000\031\000\031\000\031\000\031\000\031\000\031\000\031\000\
    \031\000\031\000\031\000\031\000\031\000\031\000\031\000\031\000\
    \031\000\031\000\031\000\031\000\031\000\031\000\031\000\031\000\
    \031\000\031\000\082\000\082\000\082\000\082\000\082\000\082\000\
    \082\000\082\000\255\255\255\255\255\255\255\255\255\255\255\255\
    \096\000\096\000\096\000\096\000\096\000\096\000\096\000\096\000\
    \096\000\096\000\255\255\255\255\255\255\255\255\082\000\255\255\
    \255\255\096\000\096\000\096\000\096\000\096\000\096\000\196\000\
    \196\000\196\000\196\000\196\000\196\000\196\000\196\000\196\000\
    \196\000\082\000\201\000\201\000\201\000\201\000\201\000\201\000\
    \201\000\201\000\201\000\201\000\255\255\255\255\082\000\255\255\
    \082\000\096\000\096\000\096\000\096\000\096\000\096\000\031\000\
    \031\000\031\000\031\000\031\000\031\000\031\000\031\000\031\000\
    \031\000\031\000\031\000\031\000\031\000\031\000\031\000\031\000\
    \031\000\031\000\031\000\031\000\031\000\031\000\255\255\031\000\
    \031\000\031\000\031\000\031\000\031\000\031\000\031\000\031\000\
    \031\000\031\000\031\000\031\000\031\000\031\000\031\000\031\000\
    \031\000\031\000\031\000\031\000\031\000\031\000\031\000\031\000\
    \031\000\031\000\031\000\031\000\031\000\031\000\032\000\031\000\
    \031\000\031\000\031\000\031\000\031\000\031\000\031\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\255\255\255\255\255\255\255\255\032\000\255\255\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\103\000\103\000\103\000\103\000\103\000\103\000\
    \103\000\103\000\103\000\103\000\255\255\255\255\255\255\255\255\
    \255\255\255\255\111\000\103\000\103\000\103\000\103\000\103\000\
    \103\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\111\000\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\103\000\103\000\103\000\103\000\103\000\
    \103\000\111\000\111\000\111\000\111\000\111\000\111\000\111\000\
    \111\000\111\000\111\000\255\255\255\255\255\255\255\255\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\255\255\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\033\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\033\000\
    \033\000\033\000\033\000\033\000\033\000\033\000\033\000\033\000\
    \033\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \033\000\033\000\033\000\033\000\033\000\033\000\033\000\033\000\
    \033\000\033\000\033\000\033\000\033\000\033\000\033\000\033\000\
    \033\000\033\000\033\000\033\000\033\000\033\000\033\000\033\000\
    \033\000\033\000\255\255\255\255\255\255\255\255\033\000\255\255\
    \033\000\033\000\033\000\033\000\033\000\033\000\033\000\033\000\
    \033\000\033\000\033\000\033\000\033\000\033\000\033\000\033\000\
    \033\000\033\000\033\000\033\000\033\000\033\000\033\000\033\000\
    \033\000\033\000\110\000\110\000\255\255\255\255\110\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\110\000\255\255\110\000\155\000\255\255\255\255\155\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\110\000\110\000\110\000\110\000\110\000\110\000\110\000\
    \110\000\110\000\110\000\255\255\155\000\255\255\255\255\255\255\
    \255\255\155\000\255\255\255\255\155\000\255\255\255\255\255\255\
    \255\255\155\000\255\255\255\255\255\255\255\255\255\255\033\000\
    \033\000\033\000\033\000\033\000\033\000\033\000\033\000\033\000\
    \033\000\033\000\033\000\033\000\033\000\033\000\033\000\033\000\
    \033\000\033\000\033\000\033\000\033\000\033\000\255\255\033\000\
    \033\000\033\000\033\000\033\000\033\000\033\000\033\000\033\000\
    \033\000\033\000\033\000\033\000\033\000\033\000\033\000\033\000\
    \033\000\033\000\033\000\033\000\033\000\033\000\033\000\033\000\
    \033\000\033\000\033\000\033\000\033\000\033\000\255\255\033\000\
    \033\000\033\000\033\000\033\000\033\000\033\000\033\000\035\000\
    \255\255\255\255\035\000\035\000\035\000\155\000\255\255\255\255\
    \255\255\035\000\036\000\035\000\035\000\036\000\036\000\036\000\
    \255\255\255\255\255\255\255\255\036\000\255\255\036\000\036\000\
    \035\000\255\255\035\000\035\000\035\000\035\000\035\000\255\255\
    \255\255\255\255\255\255\036\000\255\255\036\000\036\000\036\000\
    \036\000\036\000\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\037\000\255\255\255\255\037\000\037\000\037\000\255\255\
    \255\255\255\255\035\000\037\000\035\000\037\000\037\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\036\000\255\255\036\000\
    \255\255\255\255\037\000\255\255\037\000\037\000\037\000\037\000\
    \037\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\035\000\255\255\035\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\036\000\255\255\036\000\
    \255\255\255\255\255\255\255\255\037\000\255\255\037\000\255\255\
    \255\255\110\000\255\255\255\255\255\255\038\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\038\000\038\000\
    \038\000\038\000\038\000\038\000\038\000\038\000\038\000\038\000\
    \255\255\255\255\155\000\255\255\037\000\255\255\037\000\038\000\
    \038\000\038\000\038\000\038\000\038\000\038\000\038\000\038\000\
    \038\000\038\000\038\000\038\000\038\000\038\000\038\000\038\000\
    \038\000\038\000\038\000\038\000\038\000\038\000\038\000\038\000\
    \038\000\255\255\255\255\255\255\255\255\038\000\255\255\038\000\
    \038\000\038\000\038\000\038\000\038\000\038\000\038\000\038\000\
    \038\000\038\000\038\000\038\000\038\000\038\000\038\000\038\000\
    \038\000\038\000\038\000\038\000\038\000\038\000\038\000\038\000\
    \038\000\130\000\255\255\255\255\130\000\130\000\130\000\130\000\
    \130\000\130\000\130\000\130\000\130\000\130\000\130\000\130\000\
    \130\000\130\000\130\000\130\000\130\000\130\000\130\000\130\000\
    \130\000\130\000\130\000\130\000\130\000\130\000\255\255\255\255\
    \255\255\255\255\130\000\255\255\130\000\130\000\130\000\130\000\
    \130\000\130\000\130\000\130\000\130\000\130\000\130\000\130\000\
    \130\000\130\000\130\000\130\000\130\000\130\000\130\000\130\000\
    \130\000\130\000\130\000\130\000\130\000\130\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\038\000\038\000\
    \038\000\038\000\038\000\038\000\038\000\038\000\038\000\038\000\
    \038\000\038\000\038\000\038\000\038\000\038\000\038\000\038\000\
    \038\000\038\000\038\000\038\000\038\000\255\255\038\000\038\000\
    \038\000\038\000\038\000\038\000\038\000\038\000\038\000\038\000\
    \038\000\038\000\038\000\038\000\038\000\038\000\038\000\038\000\
    \038\000\038\000\038\000\038\000\038\000\038\000\038\000\038\000\
    \038\000\038\000\038\000\038\000\038\000\255\255\038\000\038\000\
    \038\000\038\000\038\000\038\000\038\000\038\000\042\000\255\255\
    \255\255\042\000\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\042\000\255\255\255\255\
    \042\000\042\000\042\000\255\255\255\255\255\255\042\000\042\000\
    \255\255\042\000\043\000\042\000\255\255\043\000\043\000\043\000\
    \255\255\255\255\255\255\255\255\043\000\255\255\043\000\043\000\
    \042\000\042\000\042\000\042\000\042\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\043\000\255\255\043\000\043\000\043\000\
    \043\000\043\000\255\255\255\255\255\255\255\255\255\255\044\000\
    \255\255\255\255\044\000\044\000\044\000\255\255\255\255\255\255\
    \255\255\044\000\042\000\044\000\044\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\043\000\255\255\043\000\
    \044\000\255\255\044\000\044\000\044\000\044\000\044\000\255\255\
    \255\255\255\255\045\000\255\255\255\255\045\000\045\000\045\000\
    \042\000\255\255\042\000\255\255\045\000\255\255\045\000\045\000\
    \255\255\255\255\255\255\255\255\255\255\043\000\255\255\043\000\
    \255\255\255\255\044\000\045\000\044\000\045\000\045\000\045\000\
    \045\000\045\000\255\255\255\255\255\255\046\000\255\255\255\255\
    \046\000\046\000\046\000\255\255\255\255\255\255\255\255\046\000\
    \255\255\046\000\046\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\044\000\255\255\044\000\045\000\046\000\045\000\
    \046\000\046\000\046\000\046\000\046\000\255\255\255\255\255\255\
    \047\000\255\255\255\255\047\000\047\000\047\000\255\255\255\255\
    \255\255\255\255\047\000\255\255\047\000\047\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\045\000\255\255\045\000\
    \046\000\047\000\046\000\047\000\047\000\047\000\047\000\047\000\
    \255\255\255\255\255\255\048\000\255\255\255\255\048\000\048\000\
    \048\000\255\255\255\255\255\255\255\255\048\000\255\255\048\000\
    \048\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \046\000\255\255\046\000\047\000\048\000\047\000\048\000\048\000\
    \048\000\048\000\048\000\255\255\255\255\255\255\052\000\255\255\
    \255\255\052\000\052\000\052\000\255\255\255\255\255\255\255\255\
    \052\000\255\255\052\000\052\000\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\047\000\255\255\047\000\048\000\052\000\
    \048\000\052\000\052\000\052\000\052\000\052\000\255\255\255\255\
    \255\255\053\000\255\255\255\255\053\000\053\000\053\000\255\255\
    \255\255\255\255\255\255\053\000\255\255\053\000\053\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\048\000\255\255\
    \048\000\052\000\053\000\052\000\053\000\053\000\053\000\053\000\
    \053\000\255\255\255\255\255\255\054\000\255\255\255\255\054\000\
    \054\000\054\000\255\255\255\255\255\255\255\255\054\000\255\255\
    \054\000\054\000\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\052\000\255\255\052\000\053\000\054\000\053\000\054\000\
    \054\000\054\000\054\000\054\000\255\255\255\255\255\255\056\000\
    \255\255\255\255\056\000\056\000\056\000\255\255\255\255\255\255\
    \255\255\056\000\255\255\056\000\056\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\053\000\255\255\053\000\054\000\
    \056\000\054\000\056\000\056\000\056\000\056\000\056\000\255\255\
    \255\255\255\255\058\000\255\255\255\255\058\000\058\000\058\000\
    \255\255\255\255\255\255\255\255\058\000\255\255\058\000\058\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\054\000\
    \255\255\054\000\056\000\058\000\056\000\058\000\058\000\058\000\
    \058\000\058\000\255\255\255\255\255\255\060\000\255\255\255\255\
    \060\000\060\000\060\000\255\255\255\255\255\255\255\255\060\000\
    \255\255\060\000\060\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\056\000\255\255\056\000\058\000\060\000\058\000\
    \060\000\060\000\060\000\060\000\060\000\255\255\255\255\255\255\
    \067\000\255\255\255\255\067\000\067\000\067\000\255\255\255\255\
    \255\255\255\255\067\000\255\255\067\000\067\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\058\000\255\255\058\000\
    \060\000\067\000\060\000\067\000\067\000\067\000\067\000\067\000\
    \255\255\255\255\255\255\068\000\255\255\255\255\068\000\068\000\
    \068\000\255\255\255\255\255\255\255\255\068\000\255\255\068\000\
    \068\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \060\000\255\255\060\000\067\000\068\000\067\000\068\000\068\000\
    \068\000\068\000\068\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\089\000\255\255\089\000\255\255\255\255\255\255\255\255\
    \089\000\255\255\255\255\067\000\255\255\067\000\068\000\255\255\
    \068\000\089\000\089\000\089\000\089\000\089\000\089\000\089\000\
    \089\000\089\000\089\000\106\000\255\255\255\255\106\000\106\000\
    \106\000\255\255\255\255\255\255\255\255\106\000\255\255\106\000\
    \106\000\255\255\255\255\255\255\255\255\255\255\068\000\255\255\
    \068\000\255\255\255\255\255\255\106\000\255\255\106\000\106\000\
    \106\000\106\000\106\000\255\255\255\255\089\000\255\255\255\255\
    \255\255\255\255\255\255\089\000\112\000\255\255\112\000\112\000\
    \112\000\112\000\255\255\255\255\255\255\255\255\112\000\089\000\
    \112\000\112\000\255\255\089\000\255\255\089\000\106\000\255\255\
    \106\000\089\000\255\255\255\255\255\255\112\000\255\255\112\000\
    \112\000\112\000\112\000\112\000\255\255\255\255\255\255\122\000\
    \255\255\255\255\122\000\122\000\122\000\255\255\255\255\255\255\
    \255\255\122\000\255\255\122\000\122\000\255\255\106\000\255\255\
    \106\000\255\255\255\255\255\255\255\255\255\255\255\255\112\000\
    \122\000\112\000\122\000\122\000\122\000\122\000\122\000\255\255\
    \255\255\255\255\123\000\255\255\255\255\123\000\123\000\123\000\
    \255\255\255\255\255\255\255\255\123\000\255\255\123\000\123\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\112\000\
    \255\255\112\000\122\000\123\000\122\000\123\000\123\000\123\000\
    \123\000\123\000\255\255\255\255\255\255\124\000\255\255\255\255\
    \124\000\124\000\124\000\255\255\255\255\255\255\255\255\124\000\
    \255\255\124\000\124\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\122\000\255\255\122\000\123\000\124\000\123\000\
    \124\000\124\000\124\000\124\000\124\000\255\255\255\255\255\255\
    \128\000\255\255\255\255\128\000\128\000\128\000\255\255\255\255\
    \255\255\255\255\128\000\255\255\128\000\128\000\255\255\255\255\
    \255\255\089\000\255\255\255\255\255\255\123\000\255\255\123\000\
    \124\000\128\000\124\000\128\000\128\000\128\000\128\000\128\000\
    \255\255\255\255\255\255\129\000\255\255\255\255\129\000\129\000\
    \129\000\255\255\255\255\255\255\255\255\129\000\255\255\129\000\
    \129\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \124\000\255\255\124\000\128\000\129\000\128\000\129\000\129\000\
    \129\000\129\000\129\000\255\255\255\255\255\255\255\255\131\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\131\000\255\255\
    \131\000\131\000\131\000\131\000\131\000\131\000\131\000\131\000\
    \131\000\131\000\255\255\128\000\255\255\128\000\129\000\255\255\
    \129\000\131\000\131\000\131\000\131\000\131\000\131\000\131\000\
    \131\000\131\000\131\000\131\000\131\000\131\000\131\000\131\000\
    \131\000\131\000\131\000\131\000\131\000\131\000\131\000\131\000\
    \131\000\131\000\131\000\255\255\255\255\255\255\129\000\131\000\
    \129\000\131\000\131\000\131\000\131\000\131\000\131\000\131\000\
    \131\000\131\000\131\000\131\000\131\000\131\000\131\000\131\000\
    \131\000\131\000\131\000\131\000\131\000\131\000\131\000\131\000\
    \131\000\131\000\131\000\132\000\255\255\255\255\132\000\132\000\
    \132\000\255\255\255\255\255\255\255\255\132\000\255\255\132\000\
    \132\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\132\000\255\255\132\000\132\000\
    \132\000\132\000\132\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\134\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\134\000\255\255\134\000\134\000\134\000\134\000\134\000\
    \134\000\134\000\134\000\134\000\134\000\255\255\132\000\255\255\
    \132\000\134\000\255\255\255\255\134\000\134\000\134\000\134\000\
    \134\000\134\000\134\000\134\000\134\000\134\000\134\000\134\000\
    \134\000\134\000\134\000\134\000\134\000\134\000\134\000\134\000\
    \134\000\134\000\134\000\134\000\134\000\134\000\132\000\255\255\
    \132\000\255\255\134\000\255\255\134\000\134\000\134\000\134\000\
    \134\000\134\000\134\000\134\000\134\000\134\000\134\000\134\000\
    \134\000\134\000\134\000\134\000\134\000\134\000\134\000\134\000\
    \134\000\134\000\134\000\134\000\134\000\134\000\136\000\255\255\
    \255\255\136\000\136\000\136\000\255\255\255\255\255\255\255\255\
    \136\000\137\000\136\000\136\000\137\000\137\000\137\000\255\255\
    \255\255\255\255\255\255\137\000\255\255\137\000\137\000\136\000\
    \255\255\136\000\136\000\136\000\136\000\136\000\255\255\255\255\
    \255\255\255\255\137\000\255\255\137\000\137\000\137\000\137\000\
    \137\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \147\000\255\255\255\255\147\000\147\000\147\000\255\255\255\255\
    \255\255\136\000\147\000\136\000\147\000\147\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\137\000\255\255\137\000\255\255\
    \255\255\147\000\255\255\147\000\147\000\147\000\147\000\147\000\
    \255\255\255\255\255\255\149\000\255\255\255\255\149\000\149\000\
    \149\000\136\000\255\255\136\000\255\255\149\000\255\255\149\000\
    \149\000\255\255\255\255\255\255\137\000\255\255\137\000\255\255\
    \255\255\255\255\255\255\147\000\149\000\147\000\149\000\149\000\
    \149\000\149\000\149\000\255\255\255\255\255\255\150\000\255\255\
    \255\255\150\000\150\000\150\000\255\255\255\255\255\255\255\255\
    \150\000\255\255\150\000\150\000\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\147\000\255\255\147\000\149\000\150\000\
    \149\000\150\000\150\000\150\000\150\000\150\000\255\255\255\255\
    \255\255\151\000\255\255\255\255\151\000\151\000\151\000\255\255\
    \255\255\255\255\255\255\151\000\255\255\151\000\151\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\149\000\255\255\
    \149\000\150\000\151\000\150\000\151\000\151\000\151\000\151\000\
    \151\000\255\255\255\255\255\255\152\000\255\255\255\255\152\000\
    \152\000\152\000\255\255\255\255\255\255\255\255\152\000\255\255\
    \152\000\152\000\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\150\000\255\255\150\000\151\000\152\000\151\000\152\000\
    \152\000\152\000\152\000\152\000\255\255\255\255\255\255\153\000\
    \255\255\255\255\153\000\153\000\153\000\255\255\255\255\255\255\
    \255\255\153\000\255\255\153\000\153\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\151\000\255\255\151\000\152\000\
    \153\000\152\000\153\000\153\000\153\000\153\000\153\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\152\000\
    \255\255\152\000\153\000\161\000\153\000\161\000\161\000\161\000\
    \161\000\161\000\161\000\161\000\161\000\161\000\161\000\161\000\
    \161\000\161\000\161\000\161\000\161\000\161\000\161\000\161\000\
    \161\000\161\000\161\000\161\000\161\000\161\000\161\000\255\255\
    \161\000\255\255\153\000\168\000\153\000\168\000\168\000\168\000\
    \168\000\168\000\168\000\168\000\168\000\168\000\168\000\168\000\
    \168\000\168\000\168\000\168\000\168\000\168\000\168\000\168\000\
    \168\000\168\000\168\000\168\000\168\000\168\000\168\000\169\000\
    \168\000\169\000\255\255\255\255\255\255\255\255\169\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\169\000\
    \169\000\169\000\169\000\169\000\169\000\169\000\169\000\169\000\
    \169\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\176\000\176\000\176\000\176\000\176\000\176\000\176\000\
    \176\000\176\000\176\000\169\000\255\255\255\255\255\255\255\255\
    \255\255\169\000\176\000\176\000\176\000\176\000\176\000\176\000\
    \255\255\255\255\255\255\255\255\255\255\169\000\255\255\255\255\
    \255\255\169\000\255\255\169\000\255\255\255\255\255\255\169\000\
    \183\000\183\000\183\000\183\000\183\000\183\000\183\000\183\000\
    \183\000\183\000\176\000\176\000\176\000\176\000\176\000\176\000\
    \255\255\183\000\183\000\183\000\183\000\183\000\183\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\192\000\255\255\255\255\192\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\183\000\183\000\183\000\183\000\183\000\183\000\192\000\
    \255\255\192\000\255\255\255\255\255\255\255\255\192\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\192\000\
    \192\000\192\000\192\000\192\000\192\000\192\000\192\000\192\000\
    \192\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\195\000\195\000\195\000\195\000\195\000\195\000\195\000\
    \195\000\195\000\195\000\192\000\255\255\255\255\255\255\255\255\
    \255\255\192\000\195\000\195\000\195\000\195\000\195\000\195\000\
    \255\255\255\255\255\255\255\255\255\255\192\000\255\255\255\255\
    \255\255\192\000\255\255\192\000\255\255\255\255\255\255\192\000\
    \203\000\203\000\203\000\203\000\203\000\203\000\203\000\203\000\
    \203\000\203\000\195\000\195\000\195\000\195\000\195\000\195\000\
    \255\255\203\000\203\000\203\000\203\000\203\000\203\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\203\000\203\000\203\000\203\000\203\000\203\000\208\000\
    \255\255\208\000\208\000\208\000\208\000\208\000\208\000\208\000\
    \208\000\208\000\208\000\208\000\208\000\208\000\208\000\208\000\
    \208\000\208\000\208\000\208\000\208\000\208\000\208\000\208\000\
    \208\000\208\000\208\000\255\255\214\000\208\000\214\000\214\000\
    \214\000\214\000\214\000\214\000\214\000\214\000\214\000\214\000\
    \214\000\214\000\214\000\214\000\214\000\214\000\214\000\214\000\
    \214\000\214\000\214\000\214\000\214\000\214\000\214\000\214\000\
    \255\255\255\255\214\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\192\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255";
  Lexing.lex_base_code = 
   "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\010\000\036\000\
    \000\000\000\000\012\000\000\000\000\000\000\000\002\000\000\000\
    \027\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \001\000\000\000\000\000\000\000\000\000\000\000\000\000\002\000\
    \004\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    ";
  Lexing.lex_backtrk_code = 
   "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\039\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    ";
  Lexing.lex_default_code = 
   "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\019\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    ";
  Lexing.lex_trans_code = 
   "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\001\000\000\000\036\000\036\000\000\000\036\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \001\000\000\000\000\000\001\000\022\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\007\000\001\000\000\000\000\000\
    \004\000\004\000\004\000\004\000\004\000\004\000\004\000\004\000\
    \004\000\004\000\004\000\004\000\004\000\004\000\004\000\004\000\
    \004\000\004\000\004\000\004\000\001\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\004\000\004\000\004\000\004\000\
    \004\000\004\000\004\000\004\000\004\000\004\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000";
  Lexing.lex_check_code = 
   "\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\022\000\117\000\192\000\199\000\117\000\200\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \022\000\255\255\117\000\000\000\118\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\110\000\111\000\255\255\255\255\
    \022\000\022\000\022\000\022\000\022\000\022\000\022\000\022\000\
    \022\000\022\000\110\000\110\000\110\000\110\000\110\000\110\000\
    \110\000\110\000\110\000\110\000\111\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\111\000\111\000\111\000\111\000\
    \111\000\111\000\111\000\111\000\111\000\111\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \117\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255";
  Lexing.lex_code = 
   "\255\004\255\255\005\255\255\007\255\006\255\255\003\255\000\004\
    \001\005\255\007\255\255\006\255\007\255\255\000\004\001\005\003\
    \006\002\007\255\001\255\255\000\001\255";
}

let rec token lexbuf =
  lexbuf.Lexing.lex_mem <- Array.make 8 (-1) ;   __ocaml_lex_token_rec lexbuf 0
and __ocaml_lex_token_rec lexbuf __ocaml_lex_state =
  match Lexing.new_engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 339 "src/reason_lexer.mll"
                 (
      match !preprocessor with
      | None ->
        raise (Error(Illegal_character (Lexing.lexeme_char lexbuf 0),
                     Location.curr lexbuf))
      | Some _ ->
        update_loc lexbuf None 1 false 0;
        token lexbuf )
# 1537 "src/reason_lexer.ml"

  | 1 ->
# 348 "src/reason_lexer.mll"
      ( update_loc lexbuf None 1 false 0;
        match !preprocessor with
        | None -> token lexbuf
        | Some _ -> EOL
      )
# 1546 "src/reason_lexer.ml"

  | 2 ->
# 354 "src/reason_lexer.mll"
      ( token lexbuf )
# 1551 "src/reason_lexer.ml"

  | 3 ->
# 356 "src/reason_lexer.mll"
      ( UNDERSCORE )
# 1556 "src/reason_lexer.ml"

  | 4 ->
# 358 "src/reason_lexer.mll"
      ( TILDE )
# 1561 "src/reason_lexer.ml"

  | 5 ->
# 360 "src/reason_lexer.mll"
      ( QUESTION )
# 1566 "src/reason_lexer.ml"

  | 6 ->
# 363 "src/reason_lexer.mll"
      ( OPTIONAL_NO_DEFAULT )
# 1571 "src/reason_lexer.ml"

  | 7 ->
# 365 "src/reason_lexer.mll"
      ( EXPLICITLY_PASSED_OPTIONAL )
# 1576 "src/reason_lexer.ml"

  | 8 ->
# 367 "src/reason_lexer.mll"
      ( let s = Lexing.lexeme lexbuf in
        try Hashtbl.find keyword_table s
        with Not_found -> LIDENT s )
# 1583 "src/reason_lexer.ml"

  | 9 ->
# 371 "src/reason_lexer.mll"
      ( warn_latin1 lexbuf; LIDENT (Lexing.lexeme lexbuf) )
# 1588 "src/reason_lexer.ml"

  | 10 ->
# 373 "src/reason_lexer.mll"
      ( UIDENT(Lexing.lexeme lexbuf) )
# 1593 "src/reason_lexer.ml"

  | 11 ->
# 375 "src/reason_lexer.mll"
      ( warn_latin1 lexbuf; UIDENT(Lexing.lexeme lexbuf) )
# 1598 "src/reason_lexer.ml"

  | 12 ->
# 377 "src/reason_lexer.mll"
      ( try
          INT (cvt_int_literal (Lexing.lexeme lexbuf))
        with Failure _ ->
          raise (Error(Literal_overflow "int", Location.curr lexbuf))
      )
# 1607 "src/reason_lexer.ml"

  | 13 ->
# 383 "src/reason_lexer.mll"
      ( FLOAT (remove_underscores(Lexing.lexeme lexbuf)) )
# 1612 "src/reason_lexer.ml"

  | 14 ->
# 385 "src/reason_lexer.mll"
      ( try
          INT32 (cvt_int32_literal (Lexing.lexeme lexbuf))
        with Failure _ ->
          raise (Error(Literal_overflow "int32", Location.curr lexbuf)) )
# 1620 "src/reason_lexer.ml"

  | 15 ->
# 390 "src/reason_lexer.mll"
      ( try
          INT64 (cvt_int64_literal (Lexing.lexeme lexbuf))
        with Failure _ ->
          raise (Error(Literal_overflow "int64", Location.curr lexbuf)) )
# 1628 "src/reason_lexer.ml"

  | 16 ->
# 395 "src/reason_lexer.mll"
      ( try
          NATIVEINT (cvt_nativeint_literal (Lexing.lexeme lexbuf))
        with Failure _ ->
          raise (Error(Literal_overflow "nativeint", Location.curr lexbuf)) )
# 1636 "src/reason_lexer.ml"

  | 17 ->
# 400 "src/reason_lexer.mll"
      ( reset_string_buffer();
        is_in_string := true;
        let string_start = lexbuf.lex_start_p in
        string_start_loc := Location.curr lexbuf;
        string lexbuf;
        is_in_string := false;
        lexbuf.lex_start_p <- string_start;
        STRING (get_stored_string(), None) )
# 1648 "src/reason_lexer.ml"

  | 18 ->
# 409 "src/reason_lexer.mll"
      ( reset_string_buffer();
        let delim = Lexing.lexeme lexbuf in
        let delim = String.sub delim 1 (String.length delim - 2) in
        is_in_string := true;
        let string_start = lexbuf.lex_start_p in
        string_start_loc := Location.curr lexbuf;
        quoted_string delim lexbuf;
        is_in_string := false;
        lexbuf.lex_start_p <- string_start;
        STRING (get_stored_string(), Some delim) )
# 1662 "src/reason_lexer.ml"

  | 19 ->
# 420 "src/reason_lexer.mll"
      ( update_loc lexbuf None 1 false 1;
        CHAR (Lexing.lexeme_char lexbuf 1) )
# 1668 "src/reason_lexer.ml"

  | 20 ->
# 423 "src/reason_lexer.mll"
      ( CHAR(Lexing.lexeme_char lexbuf 1) )
# 1673 "src/reason_lexer.ml"

  | 21 ->
# 425 "src/reason_lexer.mll"
      ( CHAR(char_for_backslash (Lexing.lexeme_char lexbuf 2)) )
# 1678 "src/reason_lexer.ml"

  | 22 ->
# 427 "src/reason_lexer.mll"
      ( CHAR(char_for_decimal_code lexbuf 2) )
# 1683 "src/reason_lexer.ml"

  | 23 ->
# 429 "src/reason_lexer.mll"
      ( CHAR(char_for_hexadecimal_code lexbuf 3) )
# 1688 "src/reason_lexer.ml"

  | 24 ->
# 431 "src/reason_lexer.mll"
      ( let l = Lexing.lexeme lexbuf in
        let esc = String.sub l 1 (String.length l - 1) in
        raise (Error(Illegal_escape esc, Location.curr lexbuf))
      )
# 1696 "src/reason_lexer.ml"

  | 25 ->
# 436 "src/reason_lexer.mll"
      ( let start_loc = Location.curr lexbuf  in
        comment_start_loc := [start_loc];
        reset_string_buffer ();
        let end_loc = comment lexbuf in
        let s = get_stored_string () in
        reset_string_buffer ();
        COMMENT (s, { start_loc with
                      Location.loc_end = end_loc.Location.loc_end })
      )
# 1709 "src/reason_lexer.ml"

  | 26 ->
# 446 "src/reason_lexer.mll"
      ( let loc = Location.curr lexbuf  in
        if !print_warnings then
          Location.prerr_warning loc Warnings.Comment_start;
        comment_start_loc := [loc];
        reset_string_buffer ();
        let end_loc = comment lexbuf in
        let s = get_stored_string () in
        reset_string_buffer ();
        COMMENT (s, { loc with Location.loc_end = end_loc.Location.loc_end })
      )
# 1723 "src/reason_lexer.ml"

  | 27 ->
# 457 "src/reason_lexer.mll"
      ( let loc = Location.curr lexbuf in
        Location.prerr_warning loc Warnings.Comment_not_end;
        lexbuf.Lexing.lex_curr_pos <- lexbuf.Lexing.lex_curr_pos - 1;
        let curpos = lexbuf.lex_curr_p in
        lexbuf.lex_curr_p <- { curpos with pos_cnum = curpos.pos_cnum - 1 };
        STAR
      )
# 1734 "src/reason_lexer.ml"

  | 28 ->
# 465 "src/reason_lexer.mll"
      ( SHARPOP(Lexing.lexeme lexbuf) )
# 1739 "src/reason_lexer.ml"

  | 29 ->
let
# 466 "src/reason_lexer.mll"
                                   num
# 1745 "src/reason_lexer.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_mem.(0) lexbuf.Lexing.lex_mem.(1)
and
# 467 "src/reason_lexer.mll"
                                           name
# 1750 "src/reason_lexer.ml"
= Lexing.sub_lexeme_opt lexbuf lexbuf.Lexing.lex_mem.(3) lexbuf.Lexing.lex_mem.(2) in
# 469 "src/reason_lexer.mll"
      ( update_loc lexbuf name (int_of_string num) true 0;
        token lexbuf
      )
# 1756 "src/reason_lexer.ml"

  | 30 ->
# 472 "src/reason_lexer.mll"
         ( AMPERSAND )
# 1761 "src/reason_lexer.ml"

  | 31 ->
# 473 "src/reason_lexer.mll"
         ( AMPERAMPER )
# 1766 "src/reason_lexer.ml"

  | 32 ->
# 474 "src/reason_lexer.mll"
         ( BACKQUOTE )
# 1771 "src/reason_lexer.ml"

  | 33 ->
# 475 "src/reason_lexer.mll"
         ( QUOTE )
# 1776 "src/reason_lexer.ml"

  | 34 ->
# 476 "src/reason_lexer.mll"
         ( LPAREN )
# 1781 "src/reason_lexer.ml"

  | 35 ->
# 477 "src/reason_lexer.mll"
         ( RPAREN )
# 1786 "src/reason_lexer.ml"

  | 36 ->
# 478 "src/reason_lexer.mll"
         ( STAR )
# 1791 "src/reason_lexer.ml"

  | 37 ->
# 479 "src/reason_lexer.mll"
         ( COMMA )
# 1796 "src/reason_lexer.ml"

  | 38 ->
# 480 "src/reason_lexer.mll"
         ( MINUSGREATER )
# 1801 "src/reason_lexer.ml"

  | 39 ->
# 481 "src/reason_lexer.mll"
         ( EQUALGREATER )
# 1806 "src/reason_lexer.ml"

  | 40 ->
# 482 "src/reason_lexer.mll"
         ( SHARP )
# 1811 "src/reason_lexer.ml"

  | 41 ->
# 483 "src/reason_lexer.mll"
         ( DOT )
# 1816 "src/reason_lexer.ml"

  | 42 ->
# 484 "src/reason_lexer.mll"
         ( DOTDOT )
# 1821 "src/reason_lexer.ml"

  | 43 ->
# 485 "src/reason_lexer.mll"
         ( DOTDOTDOT )
# 1826 "src/reason_lexer.ml"

  | 44 ->
# 486 "src/reason_lexer.mll"
         ( COLON )
# 1831 "src/reason_lexer.ml"

  | 45 ->
# 487 "src/reason_lexer.mll"
         ( COLONCOLON )
# 1836 "src/reason_lexer.ml"

  | 46 ->
# 488 "src/reason_lexer.mll"
         ( COLONEQUAL )
# 1841 "src/reason_lexer.ml"

  | 47 ->
# 489 "src/reason_lexer.mll"
         ( COLONGREATER )
# 1846 "src/reason_lexer.ml"

  | 48 ->
# 490 "src/reason_lexer.mll"
         ( SEMI )
# 1851 "src/reason_lexer.ml"

  | 49 ->
# 491 "src/reason_lexer.mll"
         ( SEMISEMI )
# 1856 "src/reason_lexer.ml"

  | 50 ->
# 492 "src/reason_lexer.mll"
         ( LESS )
# 1861 "src/reason_lexer.ml"

  | 51 ->
# 493 "src/reason_lexer.mll"
         ( LESSMINUS )
# 1866 "src/reason_lexer.ml"

  | 52 ->
# 494 "src/reason_lexer.mll"
         ( EQUAL )
# 1871 "src/reason_lexer.ml"

  | 53 ->
# 495 "src/reason_lexer.mll"
         ( LBRACKET )
# 1876 "src/reason_lexer.ml"

  | 54 ->
# 496 "src/reason_lexer.mll"
         ( LBRACKETBAR )
# 1881 "src/reason_lexer.ml"

  | 55 ->
# 497 "src/reason_lexer.mll"
         ( LBRACKETLESS )
# 1886 "src/reason_lexer.ml"

  | 56 ->
# 498 "src/reason_lexer.mll"
         ( LBRACKETGREATER )
# 1891 "src/reason_lexer.ml"

  | 57 ->
# 499 "src/reason_lexer.mll"
                                                   (
    let buf = Lexing.lexeme lexbuf in
    LESSIDENT (String.sub buf 1 (String.length buf - 1))
  )
# 1899 "src/reason_lexer.ml"

  | 58 ->
# 503 "src/reason_lexer.mll"
                                                        (
    let buf = Lexing.lexeme lexbuf in
    LESSSLASHIDENTGREATER (String.sub buf 2 (String.length buf - 2 - 1))
  )
# 1907 "src/reason_lexer.ml"

  | 59 ->
# 507 "src/reason_lexer.mll"
         ( RBRACKET )
# 1912 "src/reason_lexer.ml"

  | 60 ->
# 508 "src/reason_lexer.mll"
         ( LBRACE )
# 1917 "src/reason_lexer.ml"

  | 61 ->
# 509 "src/reason_lexer.mll"
         ( LBRACELESS )
# 1922 "src/reason_lexer.ml"

  | 62 ->
# 510 "src/reason_lexer.mll"
         ( BAR )
# 1927 "src/reason_lexer.ml"

  | 63 ->
# 511 "src/reason_lexer.mll"
         ( BARBAR )
# 1932 "src/reason_lexer.ml"

  | 64 ->
# 512 "src/reason_lexer.mll"
         ( BARRBRACKET )
# 1937 "src/reason_lexer.ml"

  | 65 ->
# 513 "src/reason_lexer.mll"
         ( GREATER )
# 1942 "src/reason_lexer.ml"

  | 66 ->
# 514 "src/reason_lexer.mll"
         ( GREATERGREATER )
# 1947 "src/reason_lexer.ml"

  | 67 ->
# 520 "src/reason_lexer.mll"
         ( RBRACE )
# 1952 "src/reason_lexer.ml"

  | 68 ->
# 521 "src/reason_lexer.mll"
         ( GREATERRBRACE )
# 1957 "src/reason_lexer.ml"

  | 69 ->
# 522 "src/reason_lexer.mll"
         ( LBRACKETAT )
# 1962 "src/reason_lexer.ml"

  | 70 ->
# 523 "src/reason_lexer.mll"
         ( LBRACKETPERCENT )
# 1967 "src/reason_lexer.ml"

  | 71 ->
# 524 "src/reason_lexer.mll"
          ( LBRACKETPERCENTPERCENT )
# 1972 "src/reason_lexer.ml"

  | 72 ->
# 525 "src/reason_lexer.mll"
          ( LBRACKETATAT )
# 1977 "src/reason_lexer.ml"

  | 73 ->
# 526 "src/reason_lexer.mll"
           ( LBRACKETATATAT )
# 1982 "src/reason_lexer.ml"

  | 74 ->
# 527 "src/reason_lexer.mll"
         ( BANG )
# 1987 "src/reason_lexer.ml"

  | 75 ->
# 528 "src/reason_lexer.mll"
         ( INFIXOP0 "!=" )
# 1992 "src/reason_lexer.ml"

  | 76 ->
# 529 "src/reason_lexer.mll"
          ( INFIXOP0 "!==" )
# 1997 "src/reason_lexer.ml"

  | 77 ->
# 530 "src/reason_lexer.mll"
           ( INFIXOP0 "!=" )
# 2002 "src/reason_lexer.ml"

  | 78 ->
# 531 "src/reason_lexer.mll"
            ( INFIXOP0 "!==" )
# 2007 "src/reason_lexer.ml"

  | 79 ->
# 532 "src/reason_lexer.mll"
         ( PLUS )
# 2012 "src/reason_lexer.ml"

  | 80 ->
# 533 "src/reason_lexer.mll"
         ( PLUSDOT )
# 2017 "src/reason_lexer.ml"

  | 81 ->
# 534 "src/reason_lexer.mll"
         ( PLUSEQ )
# 2022 "src/reason_lexer.ml"

  | 82 ->
# 535 "src/reason_lexer.mll"
         ( MINUS )
# 2027 "src/reason_lexer.ml"

  | 83 ->
# 536 "src/reason_lexer.mll"
         ( MINUSDOT )
# 2032 "src/reason_lexer.ml"

  | 84 ->
# 537 "src/reason_lexer.mll"
         ( LESSGREATER )
# 2037 "src/reason_lexer.ml"

  | 85 ->
# 538 "src/reason_lexer.mll"
          ( LESSSLASHGREATER )
# 2042 "src/reason_lexer.ml"

  | 86 ->
# 539 "src/reason_lexer.mll"
           ( LESSDOTDOTGREATER )
# 2047 "src/reason_lexer.ml"

  | 87 ->
# 541 "src/reason_lexer.mll"
            ( PREFIXOP(Lexing.lexeme lexbuf) )
# 2052 "src/reason_lexer.ml"

  | 88 ->
# 543 "src/reason_lexer.mll"
            ( PREFIXOP(Lexing.lexeme lexbuf) )
# 2057 "src/reason_lexer.ml"

  | 89 ->
# 545 "src/reason_lexer.mll"
            ( INFIXOP0(Lexing.lexeme lexbuf) )
# 2062 "src/reason_lexer.ml"

  | 90 ->
# 547 "src/reason_lexer.mll"
            ( INFIXOP1(Lexing.lexeme lexbuf) )
# 2067 "src/reason_lexer.ml"

  | 91 ->
# 549 "src/reason_lexer.mll"
            ( INFIXOP2(Lexing.lexeme lexbuf) )
# 2072 "src/reason_lexer.ml"

  | 92 ->
# 551 "src/reason_lexer.mll"
         ( SLASHGREATER )
# 2077 "src/reason_lexer.ml"

  | 93 ->
# 562 "src/reason_lexer.mll"
            ( INFIXOP4(Lexing.lexeme lexbuf))
# 2082 "src/reason_lexer.ml"

  | 94 ->
# 563 "src/reason_lexer.mll"
            ( PERCENT )
# 2087 "src/reason_lexer.ml"

  | 95 ->
# 565 "src/reason_lexer.mll"
            ( INFIXOP3(Lexing.lexeme lexbuf) )
# 2092 "src/reason_lexer.ml"

  | 96 ->
# 567 "src/reason_lexer.mll"
            ( INFIXOP3(Lexing.lexeme lexbuf))
# 2097 "src/reason_lexer.ml"

  | 97 ->
# 569 "src/reason_lexer.mll"
            ( INFIXOP3(Lexing.lexeme lexbuf) )
# 2102 "src/reason_lexer.ml"

  | 98 ->
# 570 "src/reason_lexer.mll"
        ( EOF )
# 2107 "src/reason_lexer.ml"

  | 99 ->
# 572 "src/reason_lexer.mll"
      ( raise (Error(Illegal_character (Lexing.lexeme_char lexbuf 0),
                     Location.curr lexbuf))
      )
# 2114 "src/reason_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; 
      __ocaml_lex_token_rec lexbuf __ocaml_lex_state

and comment lexbuf =
    __ocaml_lex_comment_rec lexbuf 155
and __ocaml_lex_comment_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 578 "src/reason_lexer.mll"
      ( comment_start_loc := (Location.curr lexbuf) :: !comment_start_loc;
        store_lexeme lexbuf;
        comment lexbuf;
      )
# 2129 "src/reason_lexer.ml"

  | 1 ->
# 583 "src/reason_lexer.mll"
      ( match !comment_start_loc with
        | [] -> assert false
        | [_] -> comment_start_loc := []; Location.curr lexbuf
        | _ :: l -> comment_start_loc := l;
                  store_lexeme lexbuf;
                  comment lexbuf;
       )
# 2140 "src/reason_lexer.ml"

  | 2 ->
# 591 "src/reason_lexer.mll"
      (
        string_start_loc := Location.curr lexbuf;
        store_string_char '"';
        is_in_string := true;
        begin try string lexbuf
        with Error (Unterminated_string, str_start) ->
          match !comment_start_loc with
          | [] -> assert false
          | loc :: _ ->
            let start = List.hd (List.rev !comment_start_loc) in
            comment_start_loc := [];
            raise (Error (Unterminated_string_in_comment (start, str_start),
                          loc))
        end;
        is_in_string := false;
        store_string_char '"';
        comment lexbuf )
# 2161 "src/reason_lexer.ml"

  | 3 ->
# 609 "src/reason_lexer.mll"
      (
        let delim = Lexing.lexeme lexbuf in
        let delim = String.sub delim 1 (String.length delim - 2) in
        string_start_loc := Location.curr lexbuf;
        store_lexeme lexbuf;
        is_in_string := true;
        begin try quoted_string delim lexbuf
        with Error (Unterminated_string, str_start) ->
          match !comment_start_loc with
          | [] -> assert false
          | loc :: _ ->
            let start = List.hd (List.rev !comment_start_loc) in
            comment_start_loc := [];
            raise (Error (Unterminated_string_in_comment (start, str_start),
                          loc))
        end;
        is_in_string := false;
        store_string_char '|';
        store_string delim;
        store_string_char '}';
        comment lexbuf )
# 2186 "src/reason_lexer.ml"

  | 4 ->
# 632 "src/reason_lexer.mll"
      ( store_lexeme lexbuf; comment lexbuf )
# 2191 "src/reason_lexer.ml"

  | 5 ->
# 634 "src/reason_lexer.mll"
      ( update_loc lexbuf None 1 false 1;
        store_lexeme lexbuf;
        comment lexbuf
      )
# 2199 "src/reason_lexer.ml"

  | 6 ->
# 639 "src/reason_lexer.mll"
      ( store_lexeme lexbuf; comment lexbuf )
# 2204 "src/reason_lexer.ml"

  | 7 ->
# 641 "src/reason_lexer.mll"
      ( store_lexeme lexbuf; comment lexbuf )
# 2209 "src/reason_lexer.ml"

  | 8 ->
# 643 "src/reason_lexer.mll"
      ( store_lexeme lexbuf; comment lexbuf )
# 2214 "src/reason_lexer.ml"

  | 9 ->
# 645 "src/reason_lexer.mll"
      ( store_lexeme lexbuf; comment lexbuf )
# 2219 "src/reason_lexer.ml"

  | 10 ->
# 647 "src/reason_lexer.mll"
      ( match !comment_start_loc with
        | [] -> assert false
        | loc :: _ ->
          let start = List.hd (List.rev !comment_start_loc) in
          comment_start_loc := [];
          raise (Error (Unterminated_comment start, loc))
      )
# 2230 "src/reason_lexer.ml"

  | 11 ->
# 655 "src/reason_lexer.mll"
      ( update_loc lexbuf None 1 false 0;
        store_lexeme lexbuf;
        comment lexbuf
      )
# 2238 "src/reason_lexer.ml"

  | 12 ->
# 660 "src/reason_lexer.mll"
      ( store_lexeme lexbuf; comment lexbuf )
# 2243 "src/reason_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; 
      __ocaml_lex_comment_rec lexbuf __ocaml_lex_state

and string lexbuf =
  lexbuf.Lexing.lex_mem <- Array.make 2 (-1) ;   __ocaml_lex_string_rec lexbuf 187
and __ocaml_lex_string_rec lexbuf __ocaml_lex_state =
  match Lexing.new_engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 664 "src/reason_lexer.mll"
      ( () )
# 2255 "src/reason_lexer.ml"

  | 1 ->
let
# 665 "src/reason_lexer.mll"
                                  space
# 2261 "src/reason_lexer.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_mem.(0) lexbuf.Lexing.lex_curr_pos in
# 666 "src/reason_lexer.mll"
      ( update_loc lexbuf None 1 false (String.length space);
        if in_comment () then store_lexeme lexbuf;
        string lexbuf
      )
# 2268 "src/reason_lexer.ml"

  | 2 ->
# 671 "src/reason_lexer.mll"
      ( if in_comment () then store_lexeme lexbuf
        else store_string_char(char_for_backslash(Lexing.lexeme_char lexbuf 1));
        string lexbuf )
# 2275 "src/reason_lexer.ml"

  | 3 ->
# 675 "src/reason_lexer.mll"
      ( if in_comment () then store_lexeme lexbuf
        else store_string_char(char_for_decimal_code lexbuf 1);
        string lexbuf )
# 2282 "src/reason_lexer.ml"

  | 4 ->
# 679 "src/reason_lexer.mll"
      ( if in_comment () then store_lexeme lexbuf
        else store_string_char(char_for_hexadecimal_code lexbuf 2);
        string lexbuf )
# 2289 "src/reason_lexer.ml"

  | 5 ->
# 683 "src/reason_lexer.mll"
      ( if in_comment ()
        then string lexbuf
        else begin
(*  Should be an error, but we are very lax.
          raise (Error (Illegal_escape (Lexing.lexeme lexbuf),
                        Location.curr lexbuf))
*)
          let loc = Location.curr lexbuf in
          Location.prerr_warning loc Warnings.Illegal_backslash;
          store_string_char (Lexing.lexeme_char lexbuf 0);
          store_string_char (Lexing.lexeme_char lexbuf 1);
          string lexbuf
        end
      )
# 2307 "src/reason_lexer.ml"

  | 6 ->
# 698 "src/reason_lexer.mll"
      ( if not (in_comment ()) then
          Location.prerr_warning (Location.curr lexbuf) Warnings.Eol_in_string;
        update_loc lexbuf None 1 false 0;
        store_lexeme lexbuf;
        string lexbuf
      )
# 2317 "src/reason_lexer.ml"

  | 7 ->
# 705 "src/reason_lexer.mll"
      ( is_in_string := false;
        raise (Error (Unterminated_string, !string_start_loc)) )
# 2323 "src/reason_lexer.ml"

  | 8 ->
# 708 "src/reason_lexer.mll"
      ( store_string_char(Lexing.lexeme_char lexbuf 0);
        string lexbuf )
# 2329 "src/reason_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; 
      __ocaml_lex_string_rec lexbuf __ocaml_lex_state

and quoted_string delim lexbuf =
    __ocaml_lex_quoted_string_rec delim lexbuf 206
and __ocaml_lex_quoted_string_rec delim lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 713 "src/reason_lexer.mll"
      ( update_loc lexbuf None 1 false 0;
        store_lexeme lexbuf;
        quoted_string delim lexbuf
      )
# 2344 "src/reason_lexer.ml"

  | 1 ->
# 718 "src/reason_lexer.mll"
      ( is_in_string := false;
        raise (Error (Unterminated_string, !string_start_loc)) )
# 2350 "src/reason_lexer.ml"

  | 2 ->
# 721 "src/reason_lexer.mll"
      (
        let edelim = Lexing.lexeme lexbuf in
        let edelim = String.sub edelim 1 (String.length edelim - 2) in
        if delim = edelim then ()
        else (store_lexeme lexbuf; quoted_string delim lexbuf)
      )
# 2360 "src/reason_lexer.ml"

  | 3 ->
# 728 "src/reason_lexer.mll"
      ( store_string_char(Lexing.lexeme_char lexbuf 0);
        quoted_string delim lexbuf )
# 2366 "src/reason_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; 
      __ocaml_lex_quoted_string_rec delim lexbuf __ocaml_lex_state

and skip_sharp_bang lexbuf =
    __ocaml_lex_skip_sharp_bang_rec lexbuf 215
and __ocaml_lex_skip_sharp_bang_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 733 "src/reason_lexer.mll"
       ( update_loc lexbuf None 3 false 0 )
# 2378 "src/reason_lexer.ml"

  | 1 ->
# 735 "src/reason_lexer.mll"
       ( update_loc lexbuf None 1 false 0 )
# 2383 "src/reason_lexer.ml"

  | 2 ->
# 736 "src/reason_lexer.mll"
       ( () )
# 2388 "src/reason_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; 
      __ocaml_lex_skip_sharp_bang_rec lexbuf __ocaml_lex_state

;;

# 738 "src/reason_lexer.mll"
 

  let token_with_comments lexbuf =
    match !preprocessor with
    | None -> token lexbuf
    | Some (_init, preprocess) -> preprocess token lexbuf

  let last_comments = ref []
  let rec token lexbuf =
    match token_with_comments lexbuf with
        COMMENT (s, comment_loc) ->
          last_comments := (s, comment_loc) :: !last_comments;
          token lexbuf
      | tok -> tok
  let comments () = List.rev !last_comments

  let init () =
    is_in_string := false;
    last_comments := [];
    comment_start_loc := [];
    match !preprocessor with
    | None -> ()
    | Some (init, _preprocess) -> init ()

  let set_preprocessor init preprocess =
    preprocessor := Some (init, preprocess)


# 2424 "src/reason_lexer.ml"
